@@ -3,10 +3,12 @@ OC.L10N.register(
     {
     "Unknown error" : "Unbekannter Fehler",
     "Files" : "Dateien",
-    "Delete" : "Löschen",
-    "Unshare" : "Teilung zurücknehmen",
     "Download" : "Herunterladen",
+    "Delete" : "Löschen",
+    "Details" : "Details",
     "Error" : "Fehler",
+    "Upload" : "Hochladen",
+    "New folder" : "Neuer Ordner",
     "A new file or folder has been <strong>created</strong>" : "Eine neue Datei oder ein neuer Ordner wurde <strong>erstellt</strong>",
     "A file or folder has been <strong>changed</strong>" : "Eine Datei oder ein Ordner hat sich <strong>geändert</strong>",
     "A file or folder has been <strong>deleted</strong>" : "Eine Datei oder ein Ordner wurde <strong>gelöscht</strong>",
@@ -18,8 +20,6 @@ OC.L10N.register(
     "%2$s deleted %1$s" : "%2$s löschte %1$s",
     "Save" : "Speichern",
     "Settings" : "Einstellungen",
-    "New folder" : "Neuer Ordner",
-    "Upload" : "Hochladen",
     "Cancel upload" : "Hochladen abbrechen"
 },
 "nplurals=2; plural=(n != 1);");
