@@ -1,39 +1,44 @@
 <?php
 /**
- * ownCloud
+ * @author Björn Schießle <schiessle@owncloud.com>
+ * @author Joas Schilling <nickvergessen@owncloud.com>
+ * @author Michael Gapczynski <GapczynskiM@gmail.com>
+ * @author Morris Jobke <hey@morrisjobke.de>
+ * @author Robin Appelman <icewind@owncloud.com>
+ * @author Roeland Jago Douma <roeland@famdouma.nl>
+ * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @author Michael Gapczynski
- * @copyright 2013 Michael Gapczynski mtgap@owncloud.com
+ * @copyright Copyright (c) 2015, ownCloud, Inc.
+ * @license AGPL-3.0
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or any later version.
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3,
+ * as published by the Free Software Foundation.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License, version 3,
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>
  *
- * You should have received a copy of the GNU Affero General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 namespace OC\Files\Cache;
 
 class Shared_Updater {
 
-	// shares which can be removed from oc_share after the delete operation was successful
-	static private $toRemove = array();
-
 	/**
-	 * walk up the users file tree and update the etags
-	 * @param string $user
-	 * @param string $path
+	 * Walk up the users file tree and update the etags.
+	 *
+	 * @param string $user user id
+	 * @param string $path share mount point path, relative to the user's "files" folder
 	 */
 	static private function correctUsersFolder($user, $path) {
 		// $path points to the mount point which is a virtual folder, so we start with
 		// the parent
+		$path = '/' . ltrim($path, '/');
 		$path = '/files' . dirname($path);
 		\OC\Files\Filesystem::initMountPoints($user);
 		$view = new \OC\Files\View('/' . $user);
@@ -48,68 +53,52 @@ class Shared_Updater {
 		}
 	}
 
-	/**
-	* Correct the parent folders' ETags for all users shared the file at $target
-	*
-	* @param string $target
-	*/
-	static public function correctFolders($target) {
-
-		// ignore part files
-		if (pathinfo($target, PATHINFO_EXTENSION) === 'part') {
-			return false;
-		}
-
-		// Correct Shared folders of other users shared with
-		$shares = \OCA\Files_Sharing\Helper::getSharesFromItem($target);
-
-		foreach ($shares as $share) {
-			if ((int)$share['share_type'] === \OCP\Share::SHARE_TYPE_USER) {
-				self::correctUsersFolder($share['share_with'], $share['file_target']);
-			} elseif ((int)$share['share_type'] === \OCP\Share::SHARE_TYPE_GROUP) {
-				$users = \OC_Group::usersInGroup($share['share_with']);
-				foreach ($users as $user) {
-					self::correctUsersFolder($user, $share['file_target']);
-				}
-			} else { //unique name for group share
-				self::correctUsersFolder($share['share_with'], $share['file_target']);
-			}
-		}
-	}
-
-	/**
-	 * remove all shares for a given file if the file was deleted
-	 *
-	 * @param string $path
-	 */
-	private static function removeShare($path) {
-		$fileSource = self::$toRemove[$path];
-
-		if (!\OC\Files\Filesystem::file_exists($path)) {
-			$query = \OC_DB::prepare('DELETE FROM `*PREFIX*share` WHERE `file_source`=?');
-			try	{
-				\OC_DB::executeAudited($query, array($fileSource));
-			} catch (\Exception $e) {
-				\OCP\Util::writeLog('files_sharing', "can't remove share: " . $e->getMessage(), \OCP\Util::WARN);
-			}
-		}
-		unset(self::$toRemove[$path]);
-	}
-
-	/**
-	 * @param array $params
-	 */
-	static public function writeHook($params) {
-		self::correctFolders($params['path']);
-	}
-
 	/**
 	 * @param array $params
 	 */
 	static public function renameHook($params) {
-		self::correctFolders($params['newpath']);
-		self::correctFolders(pathinfo($params['oldpath'], PATHINFO_DIRNAME));
 		self::renameChildren($params['oldpath'], $params['newpath']);
+		self::moveShareToShare($params['newpath']);
+	}
+
+	/**
+	 * Fix for https://github.com/owncloud/core/issues/20769
+	 *
+	 * The owner is allowed to move their files (if they are shared) into a receiving folder
+	 * In this case we need to update the parent of the moved share. Since they are
+	 * effectively handing over ownership of the file the rest of the code needs to know
+	 * they need to build up the reshare tree.
+	 *
+	 * @param string $path
+	 */
+	static private function moveShareToShare($path) {
+		$userFolder = \OC::$server->getUserFolder();
+		$src = $userFolder->get($path);
+
+		$type = $src instanceof \OCP\Files\File ? 'file' : 'folder';
+		$shares = \OCP\Share::getItemShared($type, $src->getId());
+
+		// If the path we move is not a share we don't care
+		if (empty($shares)) {
+			return;
+		}
+
+		// Check if the destination is inside a share
+		$mountManager = \OC::$server->getMountManager();
+		$dstMount = $mountManager->find($src->getPath());
+		if (!($dstMount instanceof \OCA\Files_Sharing\SharedMount)) {
+			return;
+		}
+
+		$parenShare = $dstMount->getShare();
+
+		foreach ($shares as $share) {
+			$qb = \OC::$server->getDatabaseConnection()->getQueryBuilder();
+			$qb->update('share')
+					->set('parent', $qb->createNamedParameter($parenShare['id']))
+					->where($qb->expr()->eq('id', $qb->createNamedParameter($share['id'])))
+					->execute();
+		}
 	}
 
 	/**
@@ -117,20 +106,6 @@ class Shared_Updater {
 	 */
 	static public function deleteHook($params) {
 		$path = $params['path'];
-		self::correctFolders($path);
-
-		$fileInfo = \OC\Files\Filesystem::getFileInfo($path);
-
-		// mark file as deleted so that we can clean up the share table if
-		// the file was deleted successfully
-		self::$toRemove[$path] =  $fileInfo['fileid'];
-	}
-
-	/**
-	 * @param array $params
-	 */
-	static public function postDeleteHook($params) {
-		self::removeShare($params['path']);
 	}
 
 	/**
@@ -145,10 +120,10 @@ class Shared_Updater {
 			$shareType = $params['shareType'];
 
 			if ($shareType === \OCP\Share::SHARE_TYPE_USER) {
-				self::correctUsersFolder($shareWith, '/');
+				self::correctUsersFolder($shareWith, $params['fileTarget']);
 			} elseif ($shareType === \OCP\Share::SHARE_TYPE_GROUP) {
 				foreach (\OC_Group::usersInGroup($shareWith) as $user) {
-					self::correctUsersFolder($user, '/');
+					self::correctUsersFolder($user, $params['fileTarget']);
 				}
 			}
 		}
@@ -161,17 +136,20 @@ class Shared_Updater {
 	 */
 	static public function postUnshareHook($params) {
 
-		if ($params['itemType'] === 'file' || $params['itemType'] === 'folder') {
+		// only update etags for file/folders shared to local users/groups
+		if (($params['itemType'] === 'file' || $params['itemType'] === 'folder') &&
+				$params['shareType'] !== \OCP\Share::SHARE_TYPE_LINK &&
+				$params['shareType'] !== \OCP\Share::SHARE_TYPE_REMOTE) {
 
 			$deletedShares = isset($params['deletedShares']) ? $params['deletedShares'] : array();
 
 			foreach ($deletedShares as $share) {
 				if ($share['shareType'] === \OCP\Share::SHARE_TYPE_GROUP) {
 					foreach (\OC_Group::usersInGroup($share['shareWith']) as $user) {
-						self::correctUsersFolder($user, dirname($share['fileTarget']));
+						self::correctUsersFolder($user, $share['fileTarget']);
 					}
 				} else {
-					self::correctUsersFolder($share['shareWith'], dirname($share['fileTarget']));
+					self::correctUsersFolder($share['shareWith'], $share['fileTarget']);
 				}
 			}
 		}
@@ -186,10 +164,10 @@ class Shared_Updater {
 			foreach ($params['unsharedItems'] as $item) {
 				if ($item['shareType'] === \OCP\Share::SHARE_TYPE_GROUP) {
 					foreach (\OC_Group::usersInGroup($item['shareWith']) as $user) {
-						self::correctUsersFolder($user, dirname($item['fileTarget']));
+						self::correctUsersFolder($user, $item['fileTarget']);
 					}
 				} else {
-					self::correctUsersFolder($item['shareWith'], dirname($item['fileTarget']));
+					self::correctUsersFolder($item['shareWith'], $item['fileTarget']);
 				}
 			}
 		}
@@ -203,7 +181,7 @@ class Shared_Updater {
 	 */
 	static public function fixBrokenSharesOnAppUpdate() {
 		// delete all shares where the original file no longer exists
-		$findAndRemoveShares = \OC_DB::prepare('DELETE FROM `*PREFIX*share` ' .
+		$findAndRemoveShares = \OCP\DB::prepare('DELETE FROM `*PREFIX*share` ' .
 			'WHERE `item_type` IN (\'file\', \'folder\') ' .
 			'AND `file_source` NOT IN (SELECT `fileid` FROM `*PREFIX*filecache`)'
 		);
@@ -212,7 +190,7 @@ class Shared_Updater {
 
 	/**
 	 * rename mount point from the children if the parent was renamed
-	 * 
+	 *
 	 * @param string $oldPath old path relative to data/user/files
 	 * @param string $newPath new path relative to data/user/files
 	 */
