@@ -2,11 +2,6 @@
 $TRANSLATIONS = array(
 "Pictures" => "Imágenes",
 "Picture view" => "Vista de imágen",
-"Next" => "Siguiente",
-"Play" => "Reproducir",
-"Pause" => "Pausar",
-"Previous" => "Previo",
-"Close" => "Cerrar",
 "Error loading slideshow template" => "Error cargando plantilla de presentación.",
 "Share" => "Compartir",
 "File list" => "Lista de archivos"
