@@ -2,11 +2,6 @@
 $TRANSLATIONS = array(
 "Pictures" => "Slike",
 "Picture view" => "Slikovni pogled",
-"Next" => "Naslednja",
-"Play" => "Predvajaj",
-"Pause" => "Premor",
-"Previous" => "Predhodna",
-"Close" => "Zapri",
 "Error loading slideshow template" => "Napaka nalaganja predloge za slikovno predstavitev",
 "Share" => "Souporaba",
 "No pictures found! If you upload pictures in the files app, they will be displayed here." => "Ni najdenih slik! Če shranite slike kjerkoli med datoteke, bodo tu prikazane kot galerije.",
