@@ -1,13 +1,13 @@
 <?php
 $TRANSLATIONS = array(
+"Unable to switch channel." => "Kon niet van kanaal wisselen.",
 "Version not found" => "Versie niet gevonden",
 "Upgrade is not possible. Your web server does not have permission to remove the following directory:" => "Bijwerken is niet mogelijk. Uw webserver heeft geen permissie om de volgende directory re verwijderen:",
 "Update permissions on this directory and its content or remove it manually first." => "Werk de permissies op deze directory en de inhoud bij , of verwijder ze eerst handmatig.",
-"Unable to switch channel." => "Kon niet van kanaal wisselen.",
 "Update failed." => "Bijwerken mislukt.",
 "Fetching..." => "Ophalen...",
-"<strong>The update was unsuccessful.</strong><br />Please check logs at admin page and report this issue to the <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">ownCloud community</a>." => "<strong>De update is mislukt.</strong> Controleer de logs op de beheerpagina en meld het probleem aan de <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">ownCloud community</a>.",
-"<strong>Server error.</strong> Please check web server log file for details" => "<strong>Server fout.</strong> Verifieer het webserver logbestand voor details",
+"<strong>The update was unsuccessful.</strong><br />Please check the logs at admin page and report this issue to the <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">ownCloud community</a>." => "<strong>De update is mislukt.</strong> Controleer de logs op de beheerpagina en meld het probleem aan de <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">ownCloud community</a>.",
+"<strong>Server error.</strong> Please check the web server log file for details." => "<strong>Server fout.</strong> Verifieer het webserver logbestand voor details.",
 "Retry" => "Opniew",
 "Here is your backup:" => "Hier is uw backup:",
 "Proceed" => "Ga verder",
@@ -22,25 +22,25 @@ $TRANSLATIONS = array(
 "Make sure that your web server has write access to the following files and directories:" => "Controleer of uw webserver schrijfrechten heeft op de volgende bestanden en directories:",
 "Updates" => "Updates",
 "<strong>A new version is available: {{newVersion}}</strong>" => "<strong>Er is een nieuwe versie beschikbaar: {{newVersion}}</strong>",
-"Updates will be available in the updater app and ownCloud admin panel within a few days of an update announcement." => "Updates komen binnen enkele dagen na aankondiging beschikbaar in de Updater app en in het ownCloud beheerscherm.",
-"<strong>Up to date.</strong> <em>Checked on {{checkedAt}}</em>" => "<strong>Bijgewerkt.</strong> <em>Gecontroleerd op  {{checkedAt}}</em>",
+"Testing is everything: Therefore updates will be available here within a few days after the announcement." => "Testen is alles. Daarom komen updates hier een paar dagen na de aankondiging beschikbaar.",
+"<strong>Your version is up to date.</strong>" => "<strong>Uw versie is up to date.</strong>",
+"Checked on {{checkedAt}}" => "Gecontroleerd op {{checkedAt}}",
 "1. Check & Backup" => "1. Controleer en back-up",
 "2. Download & Extract" => "2. Download en pak uit",
 "3. Replace" => "3. Vervangen",
 "Update" => "Bijwerken",
 "Update channel:" => "Bijwerkkanaal:",
-"Please note update is possible only to a version that is greater than the one currently installed. If you upgraded from a less stable channel you will be able to upgrade from a more stable channel only after the version that is greater than you installed reaches it." => "Let op: bijwerken is alleen mogelijk naar een hoger versienummer dan de geïnstalleerde versie. Als u van een minder stabiel kanaal hebt bijgewerkt, kunt u alleen vanaf een meer stabiel kanaal bijwerken als de nieuwe stabielere versie hoger is dan de nu geïnstalleerde.",
+"<em>Rule of thumb: You can always update to a newer version. But you can never downgrade to a lower version number. Keep that in mind while using experimental channels." => "<em>Vuistregel: U kunt altijd bijwerken naar een nieuwere versie. Maar teruug naar een ouder versienummer is niet mogelijk. Onthoud dat als u werkt met experimentele versies.",
 "Updater-Backups" => "Updater-Backups",
-"Note" => "Notitie",
-"Here you can find backups of the core of your ownCloud <strong>(excluding your data)</strong> after starting an update to a newer version." => "Hier vind u de back-ups van de basis van uw your ownCloud <strong>(zonder uw gegevens)</strong> na het starten van de update naar een recentere versie.",
-"<strong>Please always backup your data separately before updating!</strong>" => "<strong>Maak een aparte back-up van uw gegevens voordat u het updaten start!</strong>",
-"Backup directory" => "Back-up map",
+"Take your time for a backup strategy: <strong>This app will only backup core files (no personal data).</strong>" => "Denk na over uw backup strategie: <strong>Deze app backupt alleen kernbestanden (geen persoonlijke bestanden).</strong>",
+"<strong>Important: Please always do a separate backup of database and personal data before updating.</strong>" => "<strong>Belangrijk: Maak altiojd een aparte backup van de database en persoonlijke gegevens voor het bijwerken.</strong>",
 "No backups found." => "Geen backups gevonden",
 "Backup" => "Back-up",
 "Done on" => "Uitgevoerd op",
 "Size" => "Grootte",
 "Download" => "Downloaden",
 "Delete" => "Verwijder",
-"Are you sure you want to delete {{entry.title}}" => "Weet u zeker dat u {{entry.title}} wilt verwijderen?"
+"Are you sure you want to delete {{entry.title}}" => "Weet u zeker dat u {{entry.title}} wilt verwijderen?",
+"Backup directory" => "Back-up map"
 );
 $PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
