@@ -11,7 +11,6 @@ OC.L10N.register(
     "Repair warning: " : "Avertiment de reparacion :",
     "Repair error: " : "Error de reparacion :",
     "Following incompatible apps have been disabled: %s" : "Las aplicacions incompatiblas seguentas son estadas desactivadas : %s",
-    "Following 3rd party apps have been disabled: %s" : "Las aplicacions tèrças partidas seguentas son estadas desactivadas : %s",
     "Invalid file provided" : "Fichièr invalid",
     "No image or file provided" : "Cap de fichièr pas provesit",
     "Unknown filetype" : "Tipe de fichièr desconegut",
@@ -27,6 +26,13 @@ OC.L10N.register(
     "Thursday" : "Dijòus",
     "Friday" : "Divendres",
     "Saturday" : "Dissabte",
+    "Sun." : "Dim.",
+    "Mon." : "Luns.",
+    "Tue." : "Març.",
+    "Wed." : "Mec.",
+    "Thu." : "Jòu.",
+    "Fri." : "Ven.",
+    "Sat." : "Sab.",
     "January" : "genièr",
     "February" : "febrièr",
     "March" : "març",
@@ -39,8 +45,21 @@ OC.L10N.register(
     "October" : "octobre",
     "November" : "novembre",
     "December" : "decembre",
+    "Jan." : "Gen.",
+    "Feb." : "Feb.",
+    "Mar." : "Mar.",
+    "Apr." : "Abr.",
+    "May." : "Mai.",
+    "Jun." : "Jun.",
+    "Jul." : "Jul.",
+    "Aug." : "Ago.",
+    "Sep." : "Sep.",
+    "Oct." : "Oct.",
+    "Nov." : "Nov.",
+    "Dec." : "Dec.",
     "Settings" : "Paramètres",
     "Saving..." : "Enregistrament…",
+    "seconds ago" : "i a qualques segondas",
     "Couldn't send reset email. Please contact your administrator." : "Impossible de mandar lo corrièl de reïnicializacion. Contactatz vòstre administrator.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Lo ligam que permet de reïnicializar vòstre senhal ven d'èsser mandat a vòstra adreça de corrièl.<br>Se o recebètz pas dins un relambi rasonable, contactatz vòstre administrator.<br>Doblidetz pas de verificar dins vòstre dorsièr corrièr indesirable / spam!",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Vòstres fichièrs son chifrats. Se avètz pas activat la clau de recuperacion, i aurà pas cap de mejan de recuperar vòstras donadas un còp lo senhal reïnicializat.<br />Se sètz pas segur(a) de çò que fasètz, contactatz vòstre administrator abans de contunhar. <br />Sètz segur que volètz contunhar ?",
@@ -78,18 +97,19 @@ OC.L10N.register(
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "L'entèsta HTTP \"{header}\" es pas configurada per èsser egala a \"{expected}\" en creant potencialament un risc religat a la seguretat e a la vida privada. Es doncas recomandat d'ajustar aqueste paramètre.",
     "Shared" : "Partejat",
     "Shared with {recipients}" : "Partejat amb {recipients}",
-    "Share" : "Partejar",
     "Error" : "Error",
     "Error while sharing" : "Error al moment de la mesa en partiment",
     "Error while unsharing" : "Error al moment de l'anullacion del partiment",
     "Error while changing permissions" : "Error al moment del cambiament de las permissions",
-    "Shared with you and the group {group} by {owner}" : "Partejat amb vos e lo grop {group} per {owner}",
-    "Shared with you by {owner}" : "Partejat amb vos per {owner}",
-    "Share with users or groups …" : "Partejar amb d'utilizaires o gropes...",
-    "Share with users, groups or remote users …" : "Partejar amb d'utilizaires, gropes, o utilizaires distants",
-    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Partejatz amb de personas sus d'autres ownClouds en utilizant la sintaxi utilizaire@exemple.com/owncloud",
-    "Share link" : "Partejar per ligam public",
+    "Error setting expiration date" : "Error al moment de l'especificacion de la data d'expiracion",
     "The public link will expire no later than {days} days after it is created" : "Aqueste ligam public expirarà al mai tard {days} jorns aprèp sa creacion.",
+    "Set expiration date" : "Especificar una data d'expiracion",
+    "Expiration" : "Expiracion",
+    "Expiration date" : "Data d'expiracion",
+    "Sending ..." : "Mandadís…",
+    "Email sent" : "Corrièl mandat",
+    "Resharing is not allowed" : "Lo repartiment es pas autorizat",
+    "Share link" : "Partejar per ligam public",
     "Link" : "Ligam",
     "Password protect" : "Protegir per un senhal",
     "Password" : "Senhal",
@@ -97,28 +117,24 @@ OC.L10N.register(
     "Allow editing" : "Permetre la modificacion",
     "Email link to person" : "Mandar lo ligam per corrièl",
     "Send" : "Mandar",
-    "Set expiration date" : "Especificar una data d'expiracion",
-    "Expiration" : "Expiracion",
-    "Expiration date" : "Data d'expiracion",
-    "An error occured. Please try again" : "Una error s'es produsida. Mercé d'ensajar tornamai",
-    "Adding user..." : "Apondon de l'utilizaire...",
+    "Shared with you and the group {group} by {owner}" : "Partejat amb vos e lo grop {group} per {owner}",
+    "Shared with you by {owner}" : "Partejat amb vos per {owner}",
+    "Shared in {item} with {user}" : "Partejat dins {item} amb {user}",
     "group" : "grop",
     "remote" : "distant",
-    "Resharing is not allowed" : "Lo repartiment es pas autorizat",
-    "Shared in {item} with {user}" : "Partejat dins {item} amb {user}",
-    "Unshare" : "Partejar pas mai",
     "notify by email" : "notificar per corrièl",
+    "Unshare" : "Partejar pas mai",
     "can share" : "pòt partejar",
     "can edit" : "pòt modificar",
-    "access control" : "contraròtle d'accès",
     "create" : "crear",
     "change" : "modificacion",
     "delete" : "suprimir",
-    "Password protected" : "Protegit per senhal",
-    "Error unsetting expiration date" : "Error al moment de la supression de la data d'expiracion",
-    "Error setting expiration date" : "Error al moment de l'especificacion de la data d'expiracion",
-    "Sending ..." : "Mandadís…",
-    "Email sent" : "Corrièl mandat",
+    "access control" : "contraròtle d'accès",
+    "An error occured. Please try again" : "Una error s'es produsida. Mercé d'ensajar tornamai",
+    "Share" : "Partejar",
+    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Partejatz amb de personas sus d'autres ownClouds en utilizant la sintaxi utilizaire@exemple.com/owncloud",
+    "Share with users or groups …" : "Partejar amb d'utilizaires o gropes...",
+    "Share with users, groups or remote users …" : "Partejar amb d'utilizaires, gropes, o utilizaires distants",
     "Warning" : "Atencion",
     "The object type is not specified." : "Lo tipe d'objècte es pas especificat.",
     "Enter new" : "Picar un novèl",
@@ -147,7 +163,6 @@ OC.L10N.register(
     "New Password" : "Senhal novèl",
     "Reset password" : "Reïnicializar lo senhal",
     "Searching other places" : "Recèrca en cors dins d'autres emplaçaments",
-    "_{count} search result in other places_::_{count} search results in other places_" : ["{count} resultat dins d'autres emplaçaments","{count} resultats dins d'autres emplaçaments"],
     "Personal" : "Personal",
     "Users" : "Utilizaires",
     "Apps" : "Aplicacions",
@@ -211,9 +226,8 @@ OC.L10N.register(
     "Please contact your administrator." : "Contactatz vòstre administrator.",
     "An internal error occured." : "Una error intèrna s'es produsida.",
     "Please try again or contact your administrator." : "Reensajatz o contactatz vòstre administrator.",
-    "Forgot your password? Reset it!" : "Senhal doblidat ? Reïnicializatz-lo !",
-    "remember" : "se remembrar de ieu",
     "Log in" : "Connexion",
+    "remember" : "se remembrar de ieu",
     "Alternative Logins" : "Identificants alternatius",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Bonjorn,<br><br>Vos informam que %s a partejat <strong>%s</strong> amb vos.<br><a href=\"%s\">Clicatz aicí per i accedir !</a><br><br>",
     "This ownCloud instance is currently in single user mode." : "Aquesta instància de ownCloud es actualament en mòde utilizaire unic.",
@@ -224,8 +238,6 @@ OC.L10N.register(
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Contactatz vòstre administrator. Se sètz administrator d'aquesta instància, configuratz lo paramètre « trusted_domain » dins lo fichièr config/config.php. Un exemple de configuracion es provesit dins lo fichièr config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "En foncion de vòstra configuracion, en tant qu'administrator podètz tanben utilizar lo boton çaijós per aprovar aqueste domeni.",
     "Add \"%s\" as trusted domain" : "Apondre \"%s\" a la lista dels domenis aprovats",
-    "%s will be updated to version %s." : "%s serà mes a jorn cap a la version %s.",
-    "The following apps will be disabled:" : "Las aplicacions seguentas seràn desactivadas :",
     "The theme %s has been disabled." : "Lo tèma %s es estat desactivat.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asseguratz-vos qu'una còpia de salvament de la banca de donadas, del dorsièr de configuracion (config) e del dorsièr de donadas (data) es estat realizada abans de començar.",
     "Start update" : "Aviar la mesa a jorn",
