@@ -12,7 +12,6 @@ OC.L10N.register(
     "Repair warning: " : "Oznámenie opravy:",
     "Repair error: " : "Chyba opravy:",
     "Following incompatible apps have been disabled: %s" : "Nasledovné nekompatibilné aplikácie boli zakázané: %s",
-    "Following 3rd party apps have been disabled: %s" : "Nasledovné aplikácie tretích strán boli zakázané: %s",
     "Invalid file provided" : "Zadaný neplatný súbor",
     "No image or file provided" : "Obrázok alebo súbor nebol zadaný",
     "Unknown filetype" : "Neznámy typ súboru",
@@ -28,6 +27,20 @@ OC.L10N.register(
     "Thursday" : "Štvrtok",
     "Friday" : "Piatok",
     "Saturday" : "Sobota",
+    "Sun." : "Ned.",
+    "Mon." : "Pon.",
+    "Tue." : "Uto.",
+    "Wed." : "Str.",
+    "Thu." : "Štv.",
+    "Fri." : "Pia.",
+    "Sat." : "Sob.",
+    "Su" : "Ne",
+    "Mo" : "Po",
+    "Tu" : "Ut",
+    "We" : "St",
+    "Th" : "Št",
+    "Fr" : "Pi",
+    "Sa" : "So",
     "January" : "Január",
     "February" : "Február",
     "March" : "Marec",
@@ -40,8 +53,21 @@ OC.L10N.register(
     "October" : "Október",
     "November" : "November",
     "December" : "December",
+    "Jan." : "Jan.",
+    "Feb." : "Feb.",
+    "Mar." : "Mar.",
+    "Apr." : "Apr.",
+    "May." : "Máj.",
+    "Jun." : "Jún.",
+    "Jul." : "Júl.",
+    "Aug." : "Aug.",
+    "Sep." : "Sep.",
+    "Oct." : "Okt.",
+    "Nov." : "Nov.",
+    "Dec." : "Dec.",
     "Settings" : "Nastavenia",
     "Saving..." : "Ukladám...",
+    "seconds ago" : "pred sekundami",
     "Couldn't send reset email. Please contact your administrator." : "Nemožno poslať email pre obnovu. Kontaktujte prosím vášho administrátora.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Odkaz na obnovu hesla bol odoslaný na váš email. Pokiaľ ho neobdržíte v primeranom čase, skontrolujte spam / priečinok nevyžiadanej pošty. <br> Ak tam nie je, kontaktujte svojho administrátora.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Súbory sú zašifrované. Ak ste nepovolili kľúč pre obnovenie, neexistuje žiadny spôsob, ako obnoviť vaše dáta po obnovení vášho hesla. <br /> Ak si nie ste istí čo urobiť, prosím skôr než budete pokračovať, obráťte sa na administrátora. <br /> Naozaj chcete pokračovať?",
@@ -76,17 +102,19 @@ OC.L10N.register(
     "Error occurred while checking server setup" : "Počas kontroly nastavenia serveru sa stala chyba",
     "Shared" : "Zdieľané",
     "Shared with {recipients}" : "Zdieľa s {recipients}",
-    "Share" : "Zdieľať",
     "Error" : "Chyba",
     "Error while sharing" : "Chyba počas zdieľania",
     "Error while unsharing" : "Chyba počas ukončenia zdieľania",
     "Error while changing permissions" : "Chyba počas zmeny oprávnení",
-    "Shared with you and the group {group} by {owner}" : "Zdieľané s vami a so skupinou {group} používateľom {owner}",
-    "Shared with you by {owner}" : "Zdieľané s vami používateľom {owner}",
-    "Share with users or groups …" : "Zdieľať s používateľmi alebo skupinami ...",
-    "Share with users, groups or remote users …" : "Zdieľať s používateľmi, skupinami alebo vzdialenými používateľmi ...",
-    "Share link" : "Zdieľať linku",
+    "Error setting expiration date" : "Chyba pri nastavení dátumu expirácie",
     "The public link will expire no later than {days} days after it is created" : "Verejný odkaz nevyprší skôr než za {days} dní po vytvorení",
+    "Set expiration date" : "Nastaviť dátum expirácie",
+    "Expiration" : "Koniec platnosti",
+    "Expiration date" : "Dátum expirácie",
+    "Sending ..." : "Odosielam ...",
+    "Email sent" : "Email odoslaný",
+    "Resharing is not allowed" : "Zdieľanie už zdieľanej položky nie je povolené",
+    "Share link" : "Zdieľať linku",
     "Link" : "Odkaz",
     "Password protect" : "Chrániť heslom",
     "Password" : "Heslo",
@@ -94,28 +122,23 @@ OC.L10N.register(
     "Allow editing" : "Povoliť úpravy",
     "Email link to person" : "Odoslať odkaz emailom",
     "Send" : "Odoslať",
-    "Set expiration date" : "Nastaviť dátum expirácie",
-    "Expiration" : "Koniec platnosti",
-    "Expiration date" : "Dátum expirácie",
-    "An error occured. Please try again" : "Nastala chyba. Skúste to znovu",
-    "Adding user..." : "Pridávam používateľa...",
+    "Shared with you and the group {group} by {owner}" : "Zdieľané s vami a so skupinou {group} používateľom {owner}",
+    "Shared with you by {owner}" : "Zdieľané s vami používateľom {owner}",
+    "Shared in {item} with {user}" : "Zdieľané v {item} s {user}",
     "group" : "skupina",
     "remote" : "vzdialený",
-    "Resharing is not allowed" : "Zdieľanie už zdieľanej položky nie je povolené",
-    "Shared in {item} with {user}" : "Zdieľané v {item} s {user}",
-    "Unshare" : "Zrušiť zdieľanie",
     "notify by email" : "informovať emailom",
+    "Unshare" : "Zrušiť zdieľanie",
     "can share" : "môže zdieľať",
     "can edit" : "môže upraviť",
-    "access control" : "prístupové práva",
     "create" : "vytvoriť",
     "change" : "zmeniť",
     "delete" : "vymazať",
-    "Password protected" : "Chránené heslom",
-    "Error unsetting expiration date" : "Chyba pri odstraňovaní dátumu expirácie",
-    "Error setting expiration date" : "Chyba pri nastavení dátumu expirácie",
-    "Sending ..." : "Odosielam ...",
-    "Email sent" : "Email odoslaný",
+    "access control" : "prístupové práva",
+    "An error occured. Please try again" : "Nastala chyba. Skúste to znovu",
+    "Share" : "Zdieľať",
+    "Share with users or groups …" : "Zdieľať s používateľmi alebo skupinami ...",
+    "Share with users, groups or remote users …" : "Zdieľať s používateľmi, skupinami alebo vzdialenými používateľmi ...",
     "Warning" : "Varovanie",
     "The object type is not specified." : "Nešpecifikovaný typ objektu.",
     "Enter new" : "Zadať nový",
@@ -144,8 +167,6 @@ OC.L10N.register(
     "New Password" : "Nové heslo",
     "Reset password" : "Obnovenie hesla",
     "Searching other places" : "Prehľadanie ostatných umiestnení",
-    "No search results in other places" : "Žiadne výsledky z prehľadávania v ostatných umiestneniach",
-    "_{count} search result in other places_::_{count} search results in other places_" : ["{count} výsledok v ostatných umiestneniach","{count} výsledky v ostatných umiestneniach","{count} výsledkov v ostatných umiestneniach"],
     "Personal" : "Osobné",
     "Users" : "Používatelia",
     "Apps" : "Aplikácie",
@@ -209,9 +230,9 @@ OC.L10N.register(
     "Please contact your administrator." : "Kontaktujte prosím vášho administrátora.",
     "An internal error occured." : "Vyskytla sa vnútorná chyba.",
     "Please try again or contact your administrator." : "Skúste to znovu, alebo sa obráťte na vášho administrátora.",
-    "Forgot your password? Reset it!" : "Zabudli ste heslo? Obnovte si ho!",
-    "remember" : "zapamätať",
     "Log in" : "Prihlásiť sa",
+    "Wrong password. Reset it?" : "Chybné heslo. Chcete ho obnoviť?",
+    "remember" : "zapamätať",
     "Alternative Logins" : "Alternatívne prihlásenie",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Dobrý deň,<br><br>Používateľ %s zdieľa s vami súbor, alebo priečinok s názvom »%s«.<br><a href=\"%s\">Pre zobrazenie kliknite na túto linku!</a><br><br>",
     "This ownCloud instance is currently in single user mode." : "Táto inštancia ownCloudu je teraz v jednopoužívateľskom móde.",
@@ -222,8 +243,7 @@ OC.L10N.register(
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Kontaktujte správcu. Ak ste správcom tejto inštancie, nakonfigurujte správne nastavenie \"trusted_domain\" v config/config.php. Vzorová konfigurácia je uvedená v config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "V závislosti na konfigurácii, vám môže byť ako správcovi umožnené použitie tlačidla nižšie pre označenie tejto domény ako dôveryhodnej.",
     "Add \"%s\" as trusted domain" : "Pridať \"%s\" ako dôveryhodnú doménu",
-    "%s will be updated to version %s." : "%s bude zaktualizovaný na verziu %s.",
-    "The following apps will be disabled:" : "Tieto aplikácie budú zakázané:",
+    "%s will be updated to version %s" : "%s bude zaktualizovaný na verziu %s.",
     "The theme %s has been disabled." : "Téma %s bola zakázaná.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pred vykonaním ďalšieho kroku sa presvedčte, že databáza, konfiguračný a dátový priečinok sú zazálohované.",
     "Start update" : "Spustiť aktualizáciu",
