@@ -2,6 +2,8 @@ OC.L10N.register(
     "core",
     {
     "Couldn't send mail to following users: %s " : "ไม่สามารถส่งอีเมลไปยังผู้ใช้: %s",
+    "Preparing update" : "เตรียมอัพเดท",
+    "Migration tests are skipped - \"update.skip-migration-test\" is activated in config.php" : "ทดสอบการย้ายจะถูกข้าม \"update.skip-migration-test\" สามารถเปิดใช้งานได้ใน config.php",
     "Turned on maintenance mode" : "เปิดโหมดการบำรุงรักษา",
     "Turned off maintenance mode" : "ปิดโหมดการบำรุงรักษา",
     "Maintenance mode is kept active" : "โหมดการบำรุงรักษาจะถูกเก็บไว้ใช้งาน",
@@ -11,8 +13,12 @@ OC.L10N.register(
     "Updated \"%s\" to %s" : "อัพเดท \"%s\" ไปยัง %s",
     "Repair warning: " : "เตือนการซ่อมแซม:",
     "Repair error: " : "เกิดข้อผิดพลาดในการซ่อมแซม:",
+    "Set log level to debug - current level: \"%s\"" : "การตั้งค่าระดับของการบันทึกเพื่อแก้ปัญหา - ระดับปัจจุบันคือ: \"%s\"",
+    "Reset log level to  \"%s\"" : "รีเซ็ทระดับการบันทึกเป็น \"%s\"",
     "Following incompatible apps have been disabled: %s" : "แอพพลิเคชันต่อไปนี้เข้ากันไม่ได้มันจะถูกปิดการใช้งาน: %s",
-    "Following 3rd party apps have been disabled: %s" : "แอพพลิเคชันของบุคคลที่ 3 ถูกปิดการใช้งาน: %s",
+    "Following apps have been disabled: %s" : "แอพฯดังต่อไปนี้ถูกปิดการใช้งาน: %s",
+    "Already up to date" : "มีอยู่แล้วถึงวันที่",
+    "File is too big" : "ไฟล์มีขนาดใหญ่เกินไป",
     "Invalid file provided" : "ระบุไฟล์ไม่ถูกต้อง",
     "No image or file provided" : "ไม่มีรูปภาพหรือไฟล์ที่ระบุ",
     "Unknown filetype" : "ไม่รู้จักชนิดของไฟล์",
@@ -28,6 +34,20 @@ OC.L10N.register(
     "Thursday" : "วันพฤหัสบดี",
     "Friday" : "วันศุกร์",
     "Saturday" : "วันเสาร์",
+    "Sun." : "อา.",
+    "Mon." : "จ.",
+    "Tue." : "อ.",
+    "Wed." : "พ.",
+    "Thu." : "พฤ.",
+    "Fri." : "ศ.",
+    "Sat." : "ส.",
+    "Su" : "อา",
+    "Mo" : "จัน",
+    "Tu" : "อัง",
+    "We" : "พุธ",
+    "Th" : "พฤ",
+    "Fr" : "ศุก",
+    "Sa" : "เสา",
     "January" : "มกราคม",
     "February" : "กุมภาพันธ์",
     "March" : "มีนาคม",
@@ -40,8 +60,21 @@ OC.L10N.register(
     "October" : "ตุลาคม",
     "November" : "พฤศจิกายน",
     "December" : "ธันวาคม",
+    "Jan." : "ม.ค.",
+    "Feb." : "ก.พ.",
+    "Mar." : "มี.ค.",
+    "Apr." : "เม.ย.",
+    "May." : "พ.ค.",
+    "Jun." : "มิ.ย.",
+    "Jul." : "ก.ค.",
+    "Aug." : "ส.ค.",
+    "Sep." : "ก.ย.",
+    "Oct." : "ต.ค.",
+    "Nov." : "พ.ย.",
+    "Dec." : "ธ.ค.",
     "Settings" : "ตั้งค่า",
     "Saving..." : "กำลังบันทึกข้อมูล...",
+    "seconds ago" : "วินาที ก่อนหน้านี้",
     "Couldn't send reset email. Please contact your administrator." : "ไม่สามารถส่งการตั้งค่าอีเมลใหม่ กรุณาติดต่อผู้ดูแลระบบ",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "ลิงค์ที่ใช้สำหรับตั้งค่ารหัสผ่านใหม่ ของคุณ ได้ถูกส่งไปยังอีเมลของคุณ หากคุณยังไม่ได้รับอีกเมล ลองไปดูที่โฟลเดอร์ สแปม/ถังขยะ ในอีเมลของคุณ <br>ทั้งนี้หากหาอีเมลไม่พบกรุณาติดต่อผู้ดูแลระบบ",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "ไฟล์ของคุณจะถูกเข้ารหัส หากคุณยังไม่ได้เปิดใช้งานรหัสการกู้คืน คุณจะได้รับข้อมูลของคุณกลับมาหลังจากที่รหัสผ่านของคุณถูกรีเซ็ต<br /> หากคุณไม่แน่ใจว่าควรทำอย่างไรโปรดติดต่อผู้ดูแลระบบของคุณก่อนที่คุณจะดำเนินการต่อไป <br /> คุณต้องการดำเนินการต่อ?",
@@ -70,29 +103,32 @@ OC.L10N.register(
     "So-so password" : "รหัสผ่านระดับปกติ",
     "Good password" : "รหัสผ่านระดับดี",
     "Strong password" : "รหัสผ่านระดับดีมาก",
-    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "เว็บเซิร์ฟเวอร์ของคุณยังไม่ถูกติดตั้งอย่างถูกต้องเพื่ออนุญาตให้ผสานข้อมูลให้ตรงกัน เนื่องจากอินเตอร์เฟซ WebDAV อาจเสียหาย",
+    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "เว็บเซิร์ฟเวอร์ของคุณยังไม่ถูกติดตั้งอย่างถูกต้องเพื่ออนุญาตให้ประสานข้อมูลให้ตรงกัน เนื่องจากอินเตอร์เฟซ WebDAV อาจเสียหาย",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "เซิร์ฟเวอร์นี้ไม่มีการเชื่อมต่ออินเทอร์เน็ตซึ่งหมายความว่าบางส่วนของคุณสมบัติ เช่น การจัดเก็บข้อมูลภายนอก การแจ้งเตือนเกี่ยวกับการปรับปรุงหรือการติดตั้งแอพพลิเคชันของบุคคลที่สามจะไม่ทำงาน การเข้าถึงไฟล์จากระยะไกลและการส่งอีเมล์แจ้งเตือนอาจจะไม่ทำงาน เราขอแนะนำให้เปิดใช้งานการเชื่อมต่ออินเทอร์เน็ตสำหรับเซิร์ฟเวอร์นี้ถ้าคุณต้องการใช้งานคุณสมบัติทั้งหมด",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "ข้อมูลไดเรกทอรีและไฟล์ของคุณอาจจะสามารถเข้าถึงได้จากอินเทอร์เน็ต ขณะที่ htaccess ไฟล์ไม่ทำงาน เราขอแนะนำให้คุณกำหนดค่าเว็บเซิร์ฟเวอร์ของคุณในทางที่ข้อมูลไดเรกทอรีไม่สามารถเข้าถึงได้หรือคุณย้ายข้อมูลไดเรกทอรีไปยังนอกเว็บเซิร์ฟเวอร์หรือเอกสาร",
     "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "ไม่ได้ตั้งค่าหน่วยความจำแคช เพื่อเพิ่มประสิทธิภาพกรุณาตั้งค่า Memcache ของคุณ สามารถดูข้อมูลเพิ่มเติมได้ที่ <a href=\"{docLink}\">เอกสาร</a>",
     "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom ไม่สามารถอ่านโดย PHP ซึ่งมีผลด้านความปลอดภัยเป็นอย่างมาก สามารถดูข้อมูลเพิ่มเติมได้ที่ <a href=\"{docLink}\">เอกสาร</a>",
+    "Your PHP version ({version}) is no longer <a href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "PHP รุ่น ({version}) ของคุณ จะไม่ได้รับ <a href=\"{phpLink}\">การสนับสนุนโดย PHP</a> เราขอแนะนำให้คุณอัพเกรดรุ่นของ PHP เพื่อความปลอดภัย",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "การกำหนดค่าพร็อกซี่ไม่ถูกต้องหรือคุณกำลังเข้าถึง ownCloud จากพร็อกซี่ที่เชื่อถือได้ ถ้าคุณไม่ได้เข้าถึง ownCloud จากพร็อกซี่ที่เชื่อถือได้ นี้เป็นปัญหาด้านความปลอดภัย คุณอาจถูกโจมดีจากผู้ไม่หวังดี อ่านข้อมูลเพิ่มเติมได้ที่ <a href=\"{docLink}\">เอกสาร</a>",
     "Error occurred while checking server setup" : "เกิดข้อผิดพลาดขณะที่ทำการตรวจสอบการติดตั้งเซิร์ฟเวอร์",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" ไม่ได้กำหนดค่าส่วนหัว Http ให้เท่ากับ \"{expected}\" นี่คือระบบการรักษาความปลอดภัยที่มีศักยภาพหรือลดความเสี่ยงที่จะเกิดขึ้นเราขอแนะนำให้ปรับการตั้งค่านี้",
     "The \"Strict-Transport-Security\" HTTP header is not configured to least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "\"Strict-Transport-Security\" ส่วนหัว HTTP ไม่ได้กำหนดค่าให้น้อยกว่า \"{seconds}\" วินาที เพื่อความปลอดภัยที่เพิ่มขึ้นเราขอแนะนำให้เปิดใช้งาน HSTS ที่อธิบายไว้ใน <a href=\"{docUrl}\">เคล็ดลับการรักษาความปลอดภัย</a> ของเรา",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "คุณกำลังเข้าถึงเว็บไซต์นี้ผ่านทาง HTTP เราขอแนะนำให้คุณกำหนดค่าเซิร์ฟเวอร์ของคุณที่จะต้องใช้ HTTPS แทนตามที่อธิบายไว้ใน <a href=\"{docUrl}\">เคล็ดลับการรักษาความปลอดภัย</a> ของเรา",
     "Shared" : "แชร์แล้ว",
     "Shared with {recipients}" : "แชร์กับ {recipients}",
-    "Share" : "แชร์",
     "Error" : "ข้อผิดพลาด",
     "Error while sharing" : "เกิดข้อผิดพลาดขณะกำลังแชร์ข้อมูล",
     "Error while unsharing" : "เกิดข้อผิดพลาดขณะกำลังยกเลิกการแชร์ข้อมูล",
     "Error while changing permissions" : "เกิดข้อผิดพลาดขณะกำลังเปลี่ยนสิทธิ์การเข้าใช้งาน",
-    "Shared with you and the group {group} by {owner}" : "ได้แชร์ให้กับคุณ และกลุ่ม {group} โดย {owner}",
-    "Shared with you by {owner}" : "ถูกแชร์ให้กับคุณโดย {owner}",
-    "Share with users or groups …" : "แชร์กับผู้ใช้หรือกลุ่ม ...",
-    "Share with users, groups or remote users …" : "แชร์กับผู้ใช้กลุ่มหรือผู้ใช้ระยะไกล ...",
-    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "แชร์กับคนใน ownClouds อื่นๆ ที่ใช้ไวยากรณ์ username@example.com/owncloud ",
-    "Share link" : "แชร์ลิงค์",
+    "Error setting expiration date" : "เกิดข้อผิดพลาดในการตั้งค่าวันที่หมดอายุ",
     "The public link will expire no later than {days} days after it is created" : "ลิงค์สาธารณะจะหมดอายุภายใน {days} วัน หลังจากที่มันถูกสร้างขึ้น",
+    "Set expiration date" : "กำหนดวันที่หมดอายุ",
+    "Expiration" : "การหมดอายุ",
+    "Expiration date" : "วันที่หมดอายุ",
+    "Sending ..." : "กำลังส่ง...",
+    "Email sent" : "ส่งอีเมล์แล้ว",
+    "Resharing is not allowed" : "ไม่อนุญาตให้แชร์ข้อมูลที่ซ้ำกัน",
+    "Share link" : "แชร์ลิงค์",
     "Link" : "ลิงค์",
     "Password protect" : "รหัสผ่านป้องกัน",
     "Password" : "รหัสผ่าน",
@@ -100,29 +136,27 @@ OC.L10N.register(
     "Allow editing" : "อนุญาตให้แก้ไข",
     "Email link to person" : "ส่งลิงก์ให้ทางอีเมล",
     "Send" : "ส่ง",
-    "Set expiration date" : "กำหนดวันที่หมดอายุ",
-    "Expiration" : "การหมดอายุ",
-    "Expiration date" : "วันที่หมดอายุ",
-    "An error occured. Please try again" : "เกิดข้อผิดพลาด กรุณาลองอีกครั้ง",
-    "Adding user..." : "กำลังเพิ่มผู้ใช้ ...",
+    "Shared with you and the group {group} by {owner}" : "ได้แชร์ให้กับคุณ และกลุ่ม {group} โดย {owner}",
+    "Shared with you by {owner}" : "ถูกแชร์ให้กับคุณโดย {owner}",
+    "Shared in {item} with {user}" : "ได้แชร์ {item} ให้กับ {user}",
     "group" : "กลุ่มผู้ใช้งาน",
     "remote" : "ระยะไกล",
-    "Resharing is not allowed" : "ไม่อนุญาตให้แชร์ข้อมูลที่ซ้ำกัน",
-    "Shared in {item} with {user}" : "ได้แชร์ {item} ให้กับ {user}",
-    "Unshare" : "ยกเลิกการแชร์",
     "notify by email" : "แจ้งเตือนทางอีเมล",
+    "Unshare" : "ยกเลิกการแชร์",
     "can share" : "สามารถแชร์ได้",
     "can edit" : "สามารถแก้ไข",
-    "access control" : "ควบคุมการเข้าถึง",
     "create" : "สร้าง",
     "change" : "เปลี่ยนแปลง",
     "delete" : "ลบ",
-    "Password protected" : "ใส่รหัสผ่านไว้",
-    "Error unsetting expiration date" : "เกิดข้อผิดพลาดขณะยกเลิกการตั้งค่าวันที่หมดอายุ",
-    "Error setting expiration date" : "เกิดข้อผิดพลาดในการตั้งค่าวันที่หมดอายุ",
-    "Sending ..." : "กำลังส่ง...",
-    "Email sent" : "ส่งอีเมล์แล้ว",
+    "access control" : "ควบคุมการเข้าถึง",
+    "Share details could not be loaded for this item." : "รายละเอียดการแชร์ไม่สามารถโหลดสำหรับรายการนี้",
+    "An error occured. Please try again" : "เกิดข้อผิดพลาด กรุณาลองอีกครั้ง",
+    "Share" : "แชร์",
+    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "แชร์กับคนใน ownClouds อื่นๆ ที่ใช้ไวยากรณ์ username@example.com/owncloud ",
+    "Share with users or groups …" : "แชร์กับผู้ใช้หรือกลุ่ม ...",
+    "Share with users, groups or remote users …" : "แชร์กับผู้ใช้กลุ่มหรือผู้ใช้ระยะไกล ...",
     "Warning" : "คำเตือน",
+    "Error while sending notification" : "เกิดข้อผิดพลาดขณะกำลังส่งการแจ้งเตือน",
     "The object type is not specified." : "ชนิดของวัตถุยังไม่ได้รับการระบุ",
     "Enter new" : "ใส่ข้อมูลใหม่",
     "Delete" : "ลบ",
@@ -140,8 +174,10 @@ OC.L10N.register(
     "Updating {productName} to version {version}, this may take a while." : "กำลังอัพเดท {productName} ไปยังรุ่น {version} อาจใช้เวลาสักครู่",
     "Please reload the page." : "โปรดโหลดหน้าเว็บใหม่",
     "The update was unsuccessful. " : "อัพเดทไม่สำเร็จ",
+    "The update was successful. There were warnings." : "การอัพเดทสำเร็จ แต่มีคำเตือนอยู่",
     "The update was successful. Redirecting you to ownCloud now." : "การอัพเดทเสร็จเรียบร้อย กำลังเปลี่ยนเส้นทางไปที่ ownCloud อยู่ในขณะนี้",
     "Couldn't reset password because the token is invalid" : "ไม่สามารถตั้งรหัสผ่านใหม่เพราะโทเค็นไม่ถูกต้อง",
+    "Couldn't reset password because the token is expired" : "ไม่สามารถตั้งค่ารหัสผ่านเพราะโทเค็นหมดอายุ",
     "Couldn't send reset email. Please make sure your username is correct." : "ไม่สามารถส่งการตั้งค่าอีเมลใหม่ กรุณาตรวจสอบชื่อผู้ใช้ของคุณให้ถูกต้อง",
     "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "ไม่สามารถส่งการตั้งค่าอีเมลใหม่เพราะไม่มีที่อยู่อีเมลนี้ กรุณาติดต่อผู้ดูแลระบบ",
     "%s password reset" : "%s ตั้งรหัสผ่านใหม่",
@@ -150,8 +186,8 @@ OC.L10N.register(
     "New Password" : "รหัสผ่านใหม่",
     "Reset password" : "เปลี่ยนรหัสผ่านใหม่",
     "Searching other places" : "กำลังค้นหาสถานที่อื่นๆ",
-    "No search results in other places" : "ไม่มีผลการค้นหาในสถานที่อื่นๆ",
-    "_{count} search result in other places_::_{count} search results in other places_" : ["{count} ผลการค้นหาในสถานที่อื่นๆ"],
+    "No search results in other folders" : "ไม่พบผลลัพธ์การค้นหาในโฟลเดอร์อื่นๆ",
+    "_{count} search result in another folder_::_{count} search results in other folders_" : ["ค้นหาพบ {count} ผลลัพธ์ในโฟลเดอร์อื่นๆ"],
     "Personal" : "ส่วนตัว",
     "Users" : "ผู้ใช้งาน",
     "Apps" : "แอปฯ",
@@ -203,7 +239,7 @@ OC.L10N.register(
     "Performance warning" : "การเตือนประสิทธิภาพการทำงาน",
     "SQLite will be used as database." : "SQLite จะถูกใช้เป็นฐานข้อมูล",
     "For larger installations we recommend to choose a different database backend." : "สำหรับการติดตั้งขนาดใหญ่เราขอแนะนำให้เลือกแบ็กเอนด์ฐานข้อมูลที่แตกต่างกัน",
-    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "โดยเฉพาะอย่างยิ่งเมื่อใช้ไคลเอนต์เดสก์ทอปสำหรับการผสานข้อมูลโดย SQLite",
+    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "โดยเฉพาะอย่างยิ่งเมื่อใช้ไคลเอนต์เดสก์ทอปสำหรับการประสานข้อมูลโดย SQLite",
     "Finish setup" : "ติดตั้งเรียบร้อยแล้ว",
     "Finishing …" : "เสร็จสิ้น ...",
     "Need help?" : "ต้องการความช่วยเหลือ?",
@@ -215,9 +251,9 @@ OC.L10N.register(
     "Please contact your administrator." : "กรุณาติดต่อผู้ดูแลระบบ",
     "An internal error occured." : "เกิดข้อผิดพลาดภายใน",
     "Please try again or contact your administrator." : "โปรดลองอีกครั้งหรือติดต่อผู้ดูแลระบบ",
-    "Forgot your password? Reset it!" : "ลืมรหัสผ่าน?",
-    "remember" : "จำรหัสผ่าน",
     "Log in" : "เข้าสู่ระบบ",
+    "Wrong password. Reset it?" : "รหัสผ่านผิด ตั้งค่าใหม่?",
+    "remember" : "จดจำฉัน",
     "Alternative Logins" : "ทางเลือกการเข้าสู่ระบบ",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "นี่คุณ,<br><br>อยากให้คุณทราบว่า %s ได้แชร์ <strong>%s</strong> กับคุณ <br><a href=\"%s\">คลิกดูที่นี่</a><br><br>",
     "This ownCloud instance is currently in single user mode." : "ขณะนี้ ownCloud อยู่ในโหมดผู้ใช้คนเดียว",
@@ -228,8 +264,10 @@ OC.L10N.register(
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "กรุณาติดต่อผู้ดูแลระบบ หากคุณเป็นผู้ดูแลระบบโปรดกำหนดค่า \"trusted_domain\" โดยตั้งค่าใน config/config.php ยกตัวอย่างระบุการตั้งค่าใน config/config.sample.php",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "ทั้งนี้ขึ้นอยู่กับการกำหนดค่าของคุณ ผู้ดูแลระบบอาจสามารถใช้ปุ่มด้านล่างเพื่อกำหนดให้โดเมนนี้มีความน่าเชื่อถือ",
     "Add \"%s\" as trusted domain" : "ได้เพิ่ม \"%s\" เป็นโดเมนที่เชื่อถือ",
-    "%s will be updated to version %s." : "%s จะถูกอัพเดทให้เป็นรุ่น %s",
-    "The following apps will be disabled:" : "แอพพลิเคชันต่อไปนี้จะปิดการใช้งาน:",
+    "App update required" : "จำเป้นต้องอัพเดทแอพฯ",
+    "%s will be updated to version %s" : "%s จะถูกอัพเดทเป็นเวอร์ชัน %s",
+    "These apps will be updated:" : "แอพพลิเคชันเหล่านี้จะถูกอัพเดท:",
+    "These incompatible apps will be disabled:" : "แอพพลิเคชันเหล่านี้เข้ากันไม่ได้จะถูกปิดการใช้งาน:",
     "The theme %s has been disabled." : "ธีม %s จะถูกปิดการใช้งาน:",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "โปรดตรวจสอบฐานข้อมูล การตั้งค่าโฟลเดอร์และโฟลเดอร์ข้อมูลจะถูกสำรองไว้ก่อนดำเนินการ",
     "Start update" : "เริ่มต้นอัพเดท",
