@@ -44,17 +44,11 @@ OC.L10N.register(
     "%s enter the database username." : "%s escriviu el nom d'usuari de la base de dades.",
     "%s enter the database name." : "%s escriviu el nom de la base de dades.",
     "%s you may not use dots in the database name" : "%s no podeu usar punts en el nom de la base de dades",
-    "MS SQL username and/or password not valid: %s" : "Nom d'usuari i/o contrasenya MS SQL no vàlids: %s",
-    "You need to enter either an existing account or the administrator." : "Heu d'escriure un compte existent o el d'administrador.",
-    "MySQL/MariaDB username and/or password not valid" : "El nom d'usuari i/o la contrasenya de MySQL/MariaDB no són vàlids",
-    "DB Error: \"%s\"" : "Error DB: \"%s\"",
-    "Offending command was: \"%s\"" : "L'ordre en conflicte és: \"%s\"",
-    "MySQL/MariaDB user '%s'@'localhost' exists already." : "L'usuari MySQL/MariaDB '%s'@'localhost' ja existeix.",
-    "Drop this user from MySQL/MariaDB" : "Esborreu aquest usuari de MySQL/MariaDB",
-    "MySQL/MariaDB user '%s'@'%%' already exists" : "L'usuari MySQL/MariaDB '%s'@'%%' ja existeix",
-    "Drop this user from MySQL/MariaDB." : "Esborreu aquest usuari de MySQL/MariaDB.",
     "Oracle connection could not be established" : "No s'ha pogut establir la connexió Oracle",
     "Oracle username and/or password not valid" : "Nom d'usuari i/o contrasenya Oracle no vàlids",
+    "DB Error: \"%s\"" : "Error DB: \"%s\"",
+    "Offending command was: \"%s\"" : "L'ordre en conflicte és: \"%s\"",
+    "You need to enter either an existing account or the administrator." : "Heu d'escriure un compte existent o el d'administrador.",
     "Offending command was: \"%s\", name: %s, password: %s" : "L'ordre en conflicte és: \"%s\", nom: %s, contrasenya: %s",
     "PostgreSQL username and/or password not valid" : "Nom d'usuari i/o contrasenya PostgreSQL no vàlids",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X no té suport i %s no funcionarà correctament en aquesta plataforma. Useu-ho al vostre risc!",
@@ -86,6 +80,7 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Ha fallat en compartir %s, perquè el rerefons de compartir per %s no pot trobar la seva font",
     "Sharing %s failed, because the file could not be found in the file cache" : "Ha fallat en compartir %s, perquè el fitxer no s'ha trobat en el fitxer cau",
     "Could not find category \"%s\"" : "No s'ha trobat la categoria \"%s\"",
+    "Apps" : "Aplicacions",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Només els caràcters següents estan permesos en el nom d'usuari: \"a-z\", \"A-Z\", \"0-9\" i \"_.@-\"",
     "A valid username must be provided" : "Heu de facilitar un nom d'usuari vàlid",
     "A valid password must be provided" : "Heu de facilitar una contrasenya vàlida",
