@@ -16,7 +16,7 @@ OC.L10N.register(
     "Library %s with a version lower than %s is required - available version %s." : "Die Bibliothek %s wird in einer früheren Version als %s benötigt - vorhanden ist Version %s.",
     "Following platforms are supported: %s" : "Die folgenden Plattformen werden unterstützt: %s",
     "ownCloud %s or higher is required." : "ownCloud %s oder höher wird benötigt.",
-    "ownCloud with a version lower than %s is required." : "ownCloud wird in einer früheren Version als %s benötigt.",
+    "ownCloud %s or lower is required." : "ownCloud %s oder niedriger wird benötigt.",
     "Help" : "Hilfe",
     "Personal" : "Persönlich",
     "Users" : "Benutzer",
@@ -45,6 +45,7 @@ OC.L10N.register(
     "File name is a reserved word" : "Der Dateiname ist ein reserviertes Wort",
     "File name contains at least one invalid character" : "Der Dateiname enthält mindestens ein ungültiges Zeichen",
     "File name is too long" : "Dateiname ist zu lang",
+    "File is currently busy, please try again later" : "Die Datei ist zur Zeit in Benutzung, bitte versuchen Sie es später noch einmal",
     "Can't read file" : "Datei kann nicht gelesen werden",
     "App directory already exists" : "Der Ordner für die App ist bereits vorhanden.",
     "Can't create app folder. Please fix permissions. %s" : "Der Ordner für die App konnte nicht angelegt werden. Bitte überprüfen Sie die Ordner- und Dateirechte und passen Sie diese entsprechend an. %s",
@@ -65,17 +66,11 @@ OC.L10N.register(
     "%s enter the database username." : "%s geben Sie den Datenbank-Benutzernamen an.",
     "%s enter the database name." : "%s geben Sie den Datenbank-Namen an.",
     "%s you may not use dots in the database name" : "%s Der Datenbank-Name darf keine Punkte enthalten",
-    "MS SQL username and/or password not valid: %s" : "MS SQL-Benutzername und/oder -Passwort ungültig: %s",
-    "You need to enter either an existing account or the administrator." : "Sie müssen entweder ein existierendes Benutzerkonto oder das Administratoren-Konto angeben.",
-    "MySQL/MariaDB username and/or password not valid" : "MySQL/MariaDB-Benutzername und/oder -Passwort sind nicht gültig",
-    "DB Error: \"%s\"" : "DB-Fehler: „%s“",
-    "Offending command was: \"%s\"" : "Fehlerhafter Befehl war: „%s“",
-    "MySQL/MariaDB user '%s'@'localhost' exists already." : "MySQL/MariaDB Benutzer '%s'@'localhost' existiert bereits.",
-    "Drop this user from MySQL/MariaDB" : "Löschen Sie diesen Benutzer von MySQL/MariaDB",
-    "MySQL/MariaDB user '%s'@'%%' already exists" : "MySQL/MariaDB-Benutzer '%s'@'%%' existiert bereits",
-    "Drop this user from MySQL/MariaDB." : "Löschen Sie diesen Benutzer von MySQL/MariaDB.",
     "Oracle connection could not be established" : "Die Oracle-Verbindung konnte nicht aufgebaut werden.",
     "Oracle username and/or password not valid" : "Oracle-Benutzername und/oder -Passwort ungültig",
+    "DB Error: \"%s\"" : "DB-Fehler: „%s“",
+    "Offending command was: \"%s\"" : "Fehlerhafter Befehl war: „%s“",
+    "You need to enter either an existing account or the administrator." : "Sie müssen entweder ein existierendes Benutzerkonto oder das Administratoren-Konto angeben.",
     "Offending command was: \"%s\", name: %s, password: %s" : "Fehlerhafter Befehl war: „%s“, Name: %s, Passwort: %s",
     "PostgreSQL username and/or password not valid" : "PostgreSQL-Benutzername und/oder -Passwort ungültig",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X wird nicht unterstützt und %s wird auf dieser Plattform nicht richtig funktionieren. Die Benutzung erfolgt auf eigene Gefahr!",
@@ -85,6 +80,7 @@ OC.L10N.register(
     "Set an admin username." : "Einen Administrator-Benutzernamen setzen.",
     "Set an admin password." : "Setze Administrator Passwort",
     "Can't create or write into the data directory %s" : "Das Datenverzeichnis %s kann nicht erstellt oder es kann darin nicht geschrieben werden.",
+    "Invalid Federated Cloud ID" : "Ungültige Federated-Cloud-ID",
     "%s shared »%s« with you" : "%s hat „%s“ mit Ihnen geteilt",
     "%s via %s" : "%s via %s",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Freigabe von %s fehlgeschlagen, da das Backend die Freigabe vom Typ %i nicht erlaubt.",
@@ -114,6 +110,7 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Freigabe von %s fehlgeschlagen, da das Freigabe-Backend für %s nicht in dieser Quelle gefunden werden konnte",
     "Sharing %s failed, because the file could not be found in the file cache" : "Freigabe von %s fehlgeschlagen, da die Datei im Datei-Cache nicht gefunden werden konnte",
     "Could not find category \"%s\"" : "Die Kategorie „%s“ konnte nicht gefunden werden",
+    "Apps" : "Apps",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Folgende Zeichen sind im Benutzernamen erlaubt: „a-z“, „A-Z“, „0-9“ und „_.@-“",
     "A valid username must be provided" : "Es muss ein gültiger Benutzername angegeben werden",
     "A valid password must be provided" : "Es muss ein gültiges Passwort angegeben werden",
