@@ -16,7 +16,7 @@ OC.L10N.register(
     "Library %s with a version lower than %s is required - available version %s." : "Bibliotek %s med en versjon lavere nn %s kreves - tilgjengelig version %s.",
     "Following platforms are supported: %s" : "Følgende plattformer støttes: %s",
     "ownCloud %s or higher is required." : "ownCloud %s eller høyere kreves.",
-    "ownCloud with a version lower than %s is required." : "ownCloud med en versjon lavere enn %s kreves.",
+    "ownCloud %s or lower is required." : "ownCloud %s eller lavere kreves.",
     "Help" : "Hjelp",
     "Personal" : "Personlig",
     "Users" : "Brukere",
@@ -49,6 +49,7 @@ OC.L10N.register(
     "Can't read file" : "Kan ikke lese fil",
     "App directory already exists" : "App-mappe finnes allerede",
     "Can't create app folder. Please fix permissions. %s" : "Kan ikke opprette app-mappe.  Vennligst ordne opp i tillatelser. %s",
+    "Archive does not contain a directory named %s" : "Arkivet inneholder ikke en mappe med navn %s",
     "No source specified when installing app" : "Ingen kilde spesifisert ved installering av app",
     "No href specified when installing app from http" : "Ingen href spesifisert ved installering av app fra http",
     "No path specified when installing app from local file" : "Ingen sti spesifisert ved installering av app fra lokal fil",
@@ -66,17 +67,11 @@ OC.L10N.register(
     "%s enter the database username." : "%s legg inn brukernavn for databasen.",
     "%s enter the database name." : "%s legg inn navnet på databasen.",
     "%s you may not use dots in the database name" : "%s du kan ikke bruke punktum i databasenavnet",
-    "MS SQL username and/or password not valid: %s" : "MS SQL-brukernavn og/eller passord ikke gyldig: %s",
-    "You need to enter either an existing account or the administrator." : "Du må legge inn enten en eksisterende konto eller administratoren.",
-    "MySQL/MariaDB username and/or password not valid" : "MySQL/MariaDB-brukernavn og/eller -passord ikke gyldig",
-    "DB Error: \"%s\"" : "Databasefeil: \"%s\"",
-    "Offending command was: \"%s\"" : "Kommandoen som feilet: \"%s\"",
-    "MySQL/MariaDB user '%s'@'localhost' exists already." : "MySQL/MariaDB-bruker '%s'@'localhost' finnes allerede.",
-    "Drop this user from MySQL/MariaDB" : "Fjern denne brukeren fra MySQL/MariaDB",
-    "MySQL/MariaDB user '%s'@'%%' already exists" : "MySQL/MariaDB-bruker '%s'@'%%' finnes allerede",
-    "Drop this user from MySQL/MariaDB." : "Fjern denne brukeren fra MySQL/MariaDB.",
     "Oracle connection could not be established" : "Klarte ikke å etablere forbindelse til Oracle",
     "Oracle username and/or password not valid" : "Oracle-brukernavn og/eller passord er ikke gyldig",
+    "DB Error: \"%s\"" : "Databasefeil: \"%s\"",
+    "Offending command was: \"%s\"" : "Kommandoen som feilet: \"%s\"",
+    "You need to enter either an existing account or the administrator." : "Du må legge inn enten en eksisterende konto eller administratoren.",
     "Offending command was: \"%s\", name: %s, password: %s" : "Kommando som feilet: \"%s\", navn: %s, passord: %s",
     "PostgreSQL username and/or password not valid" : "PostgreSQL-brukernavn og/eller passord er ikke gyldig",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X støttes ikke og %s vil ikke fungere korrekt på denne plattformen. Bruk på egen risiko!",
@@ -96,6 +91,7 @@ OC.L10N.register(
     "Sharing %s failed, because the user %s does not exist" : "Deling av %s feilet, fordi brukeren %s ikke finnes",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Deling av %s feilet, fordi brukeren %s ikke er medlem av noen grupper som %s er medlem av",
     "Sharing %s failed, because this item is already shared with %s" : "Deling av %s feilet, fordi dette elementet allerede er delt med %s",
+    "Sharing %s failed, because this item is already shared with user %s" : "Deling av %s feilet, fordi dette elementet allerede er delt med bruker %s",
     "Sharing %s failed, because the group %s does not exist" : "Deling av %s feilet, fordi gruppen %s ikke finnes",
     "Sharing %s failed, because %s is not a member of the group %s" : "Deling av %s feilet, fordi %s ikke er medlem av gruppen %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Du må oppgi et passord for å lage en offentlig lenke. Bare beskyttede lenker er tillatt",
@@ -116,6 +112,7 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Deling av %s feilet, fordi delings-serveren for %s ikke kunne finne kilden",
     "Sharing %s failed, because the file could not be found in the file cache" : "Deling av %s feilet, fordi filen ikke ble funnet i fil-mellomlageret",
     "Could not find category \"%s\"" : "Kunne ikke finne kategori \"%s\"",
+    "Apps" : "Apper",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Bare disse tegnene tillates i et brukernavn: \"a-z\", \"A-Z\", \"0-9\" og \"_.@-\"",
     "A valid username must be provided" : "Oppgi et gyldig brukernavn",
     "A valid password must be provided" : "Oppgi et gyldig passord",
