@@ -16,7 +16,7 @@ OC.L10N.register(
     "Library %s with a version lower than %s is required - available version %s." : "%s kütüphanesinin %s sürümünden daha düşük sürümü gerekli - kullanılabilir sürüm %s.",
     "Following platforms are supported: %s" : "Aşağıdaki platformlar destekleniyor: %s",
     "ownCloud %s or higher is required." : "ownCloud %s veya daha üstü gerekli.",
-    "ownCloud with a version lower than %s is required." : "ownCloud %s sürümünden daha öncesi gerekli.",
+    "ownCloud %s or lower is required." : "ownCloud %s veya daha düşük sürüm gerekli.",
     "Help" : "Yardım",
     "Personal" : "Kişisel",
     "Users" : "Kullanıcılar",
@@ -45,9 +45,11 @@ OC.L10N.register(
     "File name is a reserved word" : "Bu dosya adı özel bir kullanıma aittir",
     "File name contains at least one invalid character" : "Dosya adı en az bir geçersiz karakter içeriyor",
     "File name is too long" : "Dosya adı çok uzun",
+    "File is currently busy, please try again later" : "Dosya şu anda meşgul, lütfen daha sonra deneyin",
     "Can't read file" : "Dosya okunamıyor",
     "App directory already exists" : "Uygulama dizini zaten mevcut",
     "Can't create app folder. Please fix permissions. %s" : "Uygulama dizini oluşturulamıyor. Lütfen izinleri düzeltin. %s",
+    "Archive does not contain a directory named %s" : "Arşivde %s adında bir dizin bulunmuyor",
     "No source specified when installing app" : "Uygulama kurulurken bir kaynak belirtilmedi",
     "No href specified when installing app from http" : "Uygulama http'den kurulurken href belirtilmedi",
     "No path specified when installing app from local file" : "Uygulama yerel dosyadan kurulurken dosya yolu belirtilmedi",
@@ -65,17 +67,11 @@ OC.L10N.register(
     "%s enter the database username." : "%s veritabanı kullanıcı adını girin.",
     "%s enter the database name." : "%s veritabanı adını girin.",
     "%s you may not use dots in the database name" : "%s veritabanı adında nokta kullanamayabilirsiniz",
-    "MS SQL username and/or password not valid: %s" : "MS SQL kullanıcı adı ve/veya parolası geçersiz: %s",
-    "You need to enter either an existing account or the administrator." : "Mevcut bit hesap ya da yönetici hesabını girmelisiniz.",
-    "MySQL/MariaDB username and/or password not valid" : "MySQL/MariaDB kullanıcı adı ve/veya parolası geçersiz",
-    "DB Error: \"%s\"" : "VT Hatası: \"%s\"",
-    "Offending command was: \"%s\"" : "Saldırgan komut: \"%s\"",
-    "MySQL/MariaDB user '%s'@'localhost' exists already." : "MySQL/MariaDB kullanıcı '%s'@'localhost' zaten mevcut.",
-    "Drop this user from MySQL/MariaDB" : "Bu kullanıcıyı MySQL/MariaDB'dan at (drop)",
-    "MySQL/MariaDB user '%s'@'%%' already exists" : "MySQL/MariaDB kullanıcısı '%s'@'%%' zaten mevcut",
-    "Drop this user from MySQL/MariaDB." : "Bu kullanıcıyı MySQL/MariaDB'dan at (drop).",
     "Oracle connection could not be established" : "Oracle bağlantısı kurulamadı",
     "Oracle username and/or password not valid" : "Oracle kullanıcı adı ve/veya parolası geçerli değil",
+    "DB Error: \"%s\"" : "VT Hatası: \"%s\"",
+    "Offending command was: \"%s\"" : "Saldırgan komut: \"%s\"",
+    "You need to enter either an existing account or the administrator." : "Mevcut bit hesap ya da yönetici hesabını girmelisiniz.",
     "Offending command was: \"%s\", name: %s, password: %s" : "Hatalı komut: \"%s\", ad: %s, parola: %s",
     "PostgreSQL username and/or password not valid" : "PostgreSQL  kullanıcı adı ve/veya parolası geçerli değil",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X desteklenmiyor ve %s bu platformda düzgün çalışmayacak. Kendi riskinizle kullanın!",
@@ -85,6 +81,7 @@ OC.L10N.register(
     "Set an admin username." : "Bir yönetici kullanıcı adı ayarlayın.",
     "Set an admin password." : "Bir yönetici kullanıcı parolası ayarlayın.",
     "Can't create or write into the data directory %s" : "Veri dizini %s oluşturulamıyor veya yazılamıyor",
+    "Invalid Federated Cloud ID" : "Geçersiz Birleşmiş Bulut Kimliği",
     "%s shared »%s« with you" : "%s sizinle »%s« paylaşımında bulundu",
     "%s via %s" : "%s, %s aracılığıyla",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Arka uç %i türündeki paylaşımlara izin vermediğinden %s paylaşımı başarısız",
@@ -94,6 +91,7 @@ OC.L10N.register(
     "Sharing %s failed, because the user %s does not exist" : "%s paylaşımı, %s kullanıcısı mevcut olmadığından başarısız oldu",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s paylaşımı, %s kullanıcısının %s üyeliklerinden birine sahip olmadığından başarısız oldu",
     "Sharing %s failed, because this item is already shared with %s" : "%s paylaşımı, %s ile zaten paylaşıldığından dolayı başarısız oldu",
+    "Sharing %s failed, because this item is already shared with user %s" : "%s paylaşımı başarısız oldu çünkü bu öge zaten %s kullanıcısı ile paylaşılıyor",
     "Sharing %s failed, because the group %s does not exist" : "%s paylaşımı, %s grubu mevcut olmadığından başarısız oldu",
     "Sharing %s failed, because %s is not a member of the group %s" : "%s paylaşımı, %s kullanıcısı %s grup üyesi olmadığından başarısız oldu",
     "You need to provide a password to create a public link, only protected links are allowed" : "Herkese açık bir bağlantı oluşturmak için bir parola belirtmeniz gerekiyor. Sadece korunmuş bağlantılara izin verilmektedir",
@@ -114,6 +112,7 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s paylaşımı, %s için arka ucun kaynağını bulamamasından dolayı başarısız oldu",
     "Sharing %s failed, because the file could not be found in the file cache" : "%s paylaşımı, dosyanın dosya önbelleğinde bulunamamasınndan dolayı başarısız oldu",
     "Could not find category \"%s\"" : "\"%s\" kategorisi bulunamadı",
+    "Apps" : "Uygulamalar",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Kullanıcı adında sadece bu karakterlere izin verilmektedir: \"a-z\", \"A-Z\", \"0-9\", ve \"_.@-\"",
     "A valid username must be provided" : "Geçerli bir kullanıcı adı mutlaka sağlanmalı",
     "A valid password must be provided" : "Geçerli bir parola mutlaka sağlanmalı",
