@@ -1,28 +1,33 @@
 <?php
 /**
- * ownCloud - App Framework
+ * @author Bernhard Posselt <dev@bernhard-posselt.com>
+ * @author Morris Jobke <hey@morrisjobke.de>
+ * @author Patrick Paysant <ppaysant@linagora.com>
+ * @author Robin Appelman <icewind@owncloud.com>
+ * @author Robin McCorkell <rmccorkell@karoshi.org.uk>
+ * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @author Thomas Müller
- * @copyright 2013 Thomas Müller thomas.mueller@tmit.eu
+ * @copyright Copyright (c) 2015, ownCloud, Inc.
+ * @license AGPL-3.0
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or any later version.
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3,
+ * as published by the Free Software Foundation.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU Affero General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU Affero General Public License, version 3,
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>
  *
  */
 
 namespace OC\AppFramework\routing;
 
 use OC\AppFramework\DependencyInjection\DIContainer;
+use OCP\Route\IRouter;
 
 /**
  * Class RouteConfig
@@ -36,11 +41,10 @@ class RouteConfig {
 
 	/**
 	 * @param \OC\AppFramework\DependencyInjection\DIContainer $container
-	 * @param \OC_Router $router
-	 * @param string $pathToYml
+	 * @param \OCP\Route\IRouter $router
 	 * @internal param $appName
 	 */
-	public function __construct(DIContainer $container, \OC_Router $router, $routes) {
+	public function __construct(DIContainer $container, IRouter $router, $routes) {
 		$this->routes = $routes;
 		$this->container = $container;
 		$this->router = $router;
@@ -48,7 +52,7 @@ class RouteConfig {
 	}
 
 	/**
-	 * The routes and resource will be registered to the \OC_Router
+	 * The routes and resource will be registered to the \OCP\Route\IRouter
 	 */
 	public function register() {
 
@@ -61,7 +65,7 @@ class RouteConfig {
 
 	/**
 	 * Creates one route base on the give configuration
-	 * @param $routes
+	 * @param array $routes
 	 * @throws \UnexpectedValueException
 	 */
 	private function processSimpleRoutes($routes)
@@ -69,6 +73,12 @@ class RouteConfig {
 		$simpleRoutes = isset($routes['routes']) ? $routes['routes'] : array();
 		foreach ($simpleRoutes as $simpleRoute) {
 			$name = $simpleRoute['name'];
+			$postfix = '';
+
+			if (isset($simpleRoute['postfix'])) {
+				$postfix = $simpleRoute['postfix'];
+			}
+
 			$url = $simpleRoute['url'];
 			$verb = isset($simpleRoute['verb']) ? strtoupper($simpleRoute['verb']) : 'GET';
 
@@ -84,15 +94,21 @@ class RouteConfig {
 
 			// register the route
 			$handler = new RouteActionHandler($this->container, $controllerName, $actionName);
-			$router = $this->router->create($this->appName.'.'.$controller.'.'.$action, $url)
+			$router = $this->router->create($this->appName.'.'.$controller.'.'.$action . $postfix, $url)
 							->method($verb)
 							->action($handler);
 
-			// optionally register requirements for route. This is used to 
+			// optionally register requirements for route. This is used to
 			// tell the route parser how url parameters should be matched
 			if(array_key_exists('requirements', $simpleRoute)) {
 				$router->requirements($simpleRoute['requirements']);
 			}
+
+			// optionally register defaults for route. This is used to
+			// tell the route parser how url parameters should be default valued
+			if(array_key_exists('defaults', $simpleRoute)) {
+				$router->defaults($simpleRoute['defaults']);
+			}
 		}
 	}
 
@@ -105,7 +121,7 @@ class RouteConfig {
 	 *  - update
 	 *  - destroy
 	 *
-	 * @param $routes
+	 * @param array $routes
 	 */
 	private function processResources($routes)
 	{
@@ -122,14 +138,13 @@ class RouteConfig {
 		foreach ($resources as $resource => $config) {
 
 			// the url parameter used as id to the resource
-			$resourceId = $this->buildResourceId($resource);
 			foreach($actions as $action) {
 				$url = $config['url'];
 				$method = $action['name'];
 				$verb = isset($action['verb']) ? strtoupper($action['verb']) : 'GET';
 				$collectionAction = isset($action['on-collection']) ? $action['on-collection'] : false;
 				if (!$collectionAction) {
-					$url = $url . '/' . $resourceId;
+					$url = $url . '/{id}';
 				}
 				if (isset($action['url-postfix'])) {
 					$url = $url . '/' . $action['url-postfix'];
@@ -151,7 +166,7 @@ class RouteConfig {
 
 	/**
 	 * Based on a given route name the controller name is generated
-	 * @param $controller
+	 * @param string $controller
 	 * @return string
 	 */
 	private function buildControllerName($controller)
@@ -161,25 +176,16 @@ class RouteConfig {
 
 	/**
 	 * Based on the action part of the route name the controller method name is generated
-	 * @param $action
+	 * @param string $action
 	 * @return string
 	 */
 	private function buildActionName($action) {
 		return $this->underScoreToCamelCase($action);
 	}
 
-	/**
-	 * Generates the id used in the url part o the route url
-	 * @param $resource
-	 * @return string
-	 */
-	private function buildResourceId($resource) {
-		return '{'.$this->underScoreToCamelCase(rtrim($resource, 's')).'Id}';
-	}
-
 	/**
 	 * Underscored strings are converted to camel case strings
-	 * @param $str string
+	 * @param string $str
 	 * @return string
 	 */
 	private function underScoreToCamelCase($str) {
