@@ -1,24 +1,38 @@
 <?php
 /**
- * ownCloud
+ * @author Andreas Ergenzinger <andreas.ergenzinger@gmx.de>
+ * @author Andreas Fischer <bantu@owncloud.com>
+ * @author Bart Visscher <bartv@thisnet.nl>
+ * @author Bernhard Posselt <dev@bernhard-posselt.com>
+ * @author Felix Moeller <mail@felixmoeller.de>
+ * @author Jakob Sack <mail@jakobsack.de>
+ * @author Jan-Christoph Borchardt <hey@jancborchardt.net>
+ * @author Joas Schilling <nickvergessen@owncloud.com>
+ * @author Jörn Friedrich Dreyer <jfd@butonic.de>
+ * @author Lennart Rosam <lennart.rosam@medien-systempartner.de>
+ * @author Lukas Reschke <lukas@owncloud.com>
+ * @author Morris Jobke <hey@morrisjobke.de>
+ * @author Robin Appelman <icewind@owncloud.com>
+ * @author Robin McCorkell <rmccorkell@karoshi.org.uk>
+ * @author Scrutinizer Auto-Fixer <auto-fixer@scrutinizer-ci.com>
+ * @author Thomas Müller <thomas.mueller@tmit.eu>
+ * @author Thomas Tanghus <thomas@tanghus.net>
+ * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @author Frank Karlitschek
- * @author Jakob Sack
- * @copyright 2012 Frank Karlitschek frank@owncloud.org
- * @copyright 2013 Jakob Sack
+ * @copyright Copyright (c) 2015, ownCloud, Inc.
+ * @license AGPL-3.0
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or any later version.
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3,
+ * as published by the Free Software Foundation.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU Affero General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU Affero General Public License, version 3,
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>
  *
  */
 
@@ -30,6 +44,7 @@ class OC_L10N implements \OCP\IL10N {
 	 * cache
 	 */
 	protected static $cache = array();
+	protected static $availableLanguages = array();
 
 	/**
 	 * The best language
@@ -54,35 +69,22 @@ class OC_L10N implements \OCP\IL10N {
 	/**
 	 * Plural forms (string)
 	 */
-	private $plural_form_string = 'nplurals=2; plural=(n != 1);';
+	private $pluralFormString = 'nplurals=2; plural=(n != 1);';
 
 	/**
 	 * Plural forms (function)
 	 */
-	private $plural_form_function = null;
-
-	/**
-	 * Localization
-	 */
-	private $localizations = array(
-		'jsdate' => 'dd.mm.yy',
-		'date' => '%d.%m.%Y',
-		'datetime' => '%d.%m.%Y %H:%M:%S',
-		'time' => '%H:%M:%S',
-		'firstday' => 0);
+	private $pluralFormFunction = null;
 
 	/**
 	 * get an L10N instance
 	 * @param string $app
 	 * @param string|null $lang
-	 * @return \OC_L10N
+	 * @return \OCP\IL10N
+	 * @deprecated Use \OC::$server->getL10NFactory()->get() instead
 	 */
 	public static function get($app, $lang=null) {
-		if (is_null($lang)) {
-			return OC::$server->getL10N($app);
-		} else {
-			return new \OC_L10N($app, $lang);
-		}
+		return \OC::$server->getL10NFactory()->get($app, $lang);
 	}
 
 	/**
@@ -99,17 +101,66 @@ class OC_L10N implements \OCP\IL10N {
 	}
 
 	/**
-	 * @param string $transFile
+	 * @return string
 	 */
-	public function load($transFile) {
+	public static function setLanguageFromRequest() {
+		if (isset($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
+			$available = self::findAvailableLanguages();
+
+			// E.g. make sure that 'de' is before 'de_DE'.
+			sort($available);
+
+			$preferences = preg_split('/,\s*/', strtolower($_SERVER['HTTP_ACCEPT_LANGUAGE']));
+			foreach ($preferences as $preference) {
+				list($preferred_language) = explode(';', $preference);
+				$preferred_language = str_replace('-', '_', $preferred_language);
+				foreach ($available as $available_language) {
+					if ($preferred_language === strtolower($available_language)) {
+						if (!self::$language) {
+							self::$language = $available_language;
+						}
+						return $available_language;
+					}
+				}
+				foreach ($available as $available_language) {
+					if (substr($preferred_language, 0, 2) === $available_language) {
+						if (!self::$language) {
+							self::$language = $available_language;
+						}
+						return $available_language;
+					}
+				}
+			}
+		}
+
+		self::$language = 'en';
+		// Last try: English
+		return 'en';
+	}
+
+	/**
+	 * @param $transFile
+	 * @param bool $mergeTranslations
+	 * @return bool
+	 */
+	public function load($transFile, $mergeTranslations = false) {
 		$this->app = true;
-		include $transFile;
-		if(isset($TRANSLATIONS) && is_array($TRANSLATIONS)) {
-			$this->translations = $TRANSLATIONS;
+
+		$json = json_decode(file_get_contents($transFile), true);
+		if (!is_array($json)) {
+			return false;
 		}
-		if(isset($PLURAL_FORMS)) {
-			$this->plural_form_string = $PLURAL_FORMS;
+
+		$this->pluralFormString = $json['pluralForm'];
+		$translations = $json['translations'];
+
+		if ($mergeTranslations) {
+			$this->translations = array_merge($this->translations, $translations);
+		} else {
+			$this->translations = $translations;
 		}
+
+		return true;
 	}
 
 	protected function init() {
@@ -126,52 +177,32 @@ class OC_L10N implements \OCP\IL10N {
 
 		// Use cache if possible
 		if(array_key_exists($app.'::'.$lang, self::$cache)) {
-
 			$this->translations = self::$cache[$app.'::'.$lang]['t'];
-			$this->localizations = self::$cache[$app.'::'.$lang]['l'];
-		}
-		else{
-			$i18ndir = self::findI18nDir($app);
-			// Localization is in /l10n, Texts are in $i18ndir
+		} else{
+			$i18nDir = self::findI18nDir($app);
+			$transFile = strip_tags($i18nDir).strip_tags($lang).'.json';
+			// Texts are in $i18ndir
 			// (Just no need to define date/time format etc. twice)
-			if((OC_Helper::isSubDirectory($i18ndir.$lang.'.php', OC::$SERVERROOT.'/core/l10n/')
-				|| OC_Helper::isSubDirectory($i18ndir.$lang.'.php', OC::$SERVERROOT.'/lib/l10n/')
-				|| OC_Helper::isSubDirectory($i18ndir.$lang.'.php', OC::$SERVERROOT.'/settings')
-				|| OC_Helper::isSubDirectory($i18ndir.$lang.'.php', OC_App::getAppPath($app).'/l10n/')
+			if((OC_Helper::isSubDirectory($transFile, OC::$SERVERROOT.'/core/l10n/')
+				|| OC_Helper::isSubDirectory($transFile, OC::$SERVERROOT.'/lib/l10n/')
+				|| OC_Helper::isSubDirectory($transFile, OC::$SERVERROOT.'/settings')
+				|| OC_Helper::isSubDirectory($transFile, OC_App::getAppPath($app).'/l10n/')
 				)
-				&& file_exists($i18ndir.$lang.'.php')) {
-				// Include the file, save the data from $CONFIG
-				$transFile = strip_tags($i18ndir).strip_tags($lang).'.php';
-				include $transFile;
-				if(isset($TRANSLATIONS) && is_array($TRANSLATIONS)) {
-					$this->translations = $TRANSLATIONS;
+				&& file_exists($transFile)) {
+				// load the translations file
+				if($this->load($transFile)) {
 					//merge with translations from theme
-					$theme = OC_Config::getValue( "theme" );
-					if (!is_null($theme)) {
+					$theme = \OC::$server->getConfig()->getSystemValue('theme');
+					if (!empty($theme)) {
 						$transFile = OC::$SERVERROOT.'/themes/'.$theme.substr($transFile, strlen(OC::$SERVERROOT));
 						if (file_exists($transFile)) {
-							include $transFile;
-							if (isset($TRANSLATIONS) && is_array($TRANSLATIONS)) {
-								$this->translations = array_merge($this->translations, $TRANSLATIONS);
-							}
+							$this->load($transFile, true);
 						}
 					}
 				}
-				if(isset($PLURAL_FORMS)) {
-					$this->plural_form_string = $PLURAL_FORMS;
-				}
-			}
-
-			if(file_exists(OC::$SERVERROOT.'/core/l10n/l10n-'.$lang.'.php') && OC_Helper::isSubDirectory(OC::$SERVERROOT.'/core/l10n/l10n-'.$lang.'.php', OC::$SERVERROOT.'/core/l10n/')) {
-				// Include the file, save the data from $CONFIG
-				include OC::$SERVERROOT.'/core/l10n/l10n-'.$lang.'.php';
-				if(isset($LOCALIZATIONS) && is_array($LOCALIZATIONS)) {
-					$this->localizations = array_merge($this->localizations, $LOCALIZATIONS);
-				}
 			}
 
 			self::$cache[$app.'::'.$lang]['t'] = $this->translations;
-			self::$cache[$app.'::'.$lang]['l'] = $this->localizations;
 		}
 	}
 
@@ -287,17 +318,6 @@ class OC_L10N implements \OCP\IL10N {
 		return $this->translations;
 	}
 
-	/**
-	 * getPluralFormString
-	 * @return string containing the gettext "Plural-Forms"-string
-	 *
-	 * Returns a string like "nplurals=2; plural=(n != 1);"
-	 */
-	public function getPluralFormString() {
-		$this->init();
-		return $this->plural_form_string;
-	}
-
 	/**
 	 * getPluralFormFunction
 	 * @return string the plural form function
@@ -306,210 +326,136 @@ class OC_L10N implements \OCP\IL10N {
 	 */
 	public function getPluralFormFunction() {
 		$this->init();
-		if(is_null($this->plural_form_function)) {
-			$this->plural_form_function = $this->createPluralFormFunction($this->plural_form_string);
+		if(is_null($this->pluralFormFunction)) {
+			$this->pluralFormFunction = $this->createPluralFormFunction($this->pluralFormString);
 		}
-		return $this->plural_form_function;
-	}
-
-	/**
-	 * get localizations
-	 * @return array Fetch all localizations
-	 *
-	 * Returns an associative array with all localizations
-	 */
-	public function getLocalizations() {
-		$this->init();
-		return $this->localizations;
+		return $this->pluralFormFunction;
 	}
 
 	/**
 	 * Localization
 	 * @param string $type Type of localization
 	 * @param array|int|string $data parameters for this localization
-	 * @return String or false
+	 * @param array $options
+	 * @return string|false
 	 *
 	 * Returns the localized data.
 	 *
 	 * Implemented types:
 	 *  - date
 	 *    - Creates a date
-	 *    - l10n-field: date
 	 *    - params: timestamp (int/string)
 	 *  - datetime
 	 *    - Creates date and time
-	 *    - l10n-field: datetime
 	 *    - params: timestamp (int/string)
 	 *  - time
 	 *    - Creates a time
-	 *    - l10n-field: time
 	 *    - params: timestamp (int/string)
 	 */
-	public function l($type, $data) {
+	public function l($type, $data, $options = array()) {
+		if ($type === 'firstday') {
+			return $this->getFirstWeekDay();
+		}
+		if ($type === 'jsdate') {
+			return $this->getDateFormat();
+		}
+
 		$this->init();
+		$value = new DateTime();
+		if($data instanceof DateTime) {
+			$value = $data;
+		} elseif(is_string($data) && !is_numeric($data)) {
+			$data = strtotime($data);
+			$value->setTimestamp($data);
+		} else {
+			$value->setTimestamp($data);
+		}
+
+		// Use the language of the instance, before falling back to the current user's language
+		$locale = $this->lang;
+		if ($locale === null) {
+			$locale = self::findLanguage();
+		}
+		$locale = $this->transformToCLDRLocale($locale);
+
+		$options = array_merge(array('width' => 'long'), $options);
+		$width = $options['width'];
 		switch($type) {
-			// If you add something don't forget to add it to $localizations
-			// at the top of the page
 			case 'date':
+				return Punic\Calendar::formatDate($value, $width, $locale);
 			case 'datetime':
+				return Punic\Calendar::formatDatetime($value, $width, $locale);
 			case 'time':
-				if($data instanceof DateTime) {
-					return $data->format($this->localizations[$type]);
-				} elseif(is_string($data) && !is_numeric($data)) {
-					$data = strtotime($data);
-				}
-				$locales = array(self::findLanguage());
-				if (strlen($locales[0]) == 2) {
-					$locales[] = $locales[0].'_'.strtoupper($locales[0]);
-				}
-				setlocale(LC_TIME, $locales);
-				$format = $this->localizations[$type];
-				// Check for Windows to find and replace the %e modifier correctly
-				if (strtoupper(substr(PHP_OS, 0, 3)) == 'WIN') {
-					$format = preg_replace('#(?<!%)((?:%%)*)%e#', '\1%#d', $format);
-				}
-				return strftime($format, $data);
-				break;
-			case 'firstday':
-			case 'jsdate':
-				return $this->localizations[$type];
+				return Punic\Calendar::formatTime($value, $width, $locale);
 			default:
 				return false;
 		}
 	}
 
 	/**
-	 * Choose a language
-	 * @param array $text Associative Array with possible strings
-	 * @return String
+	 * The code (en, de, ...) of the language that is used for this OC_L10N object
 	 *
-	 * $text is an array 'de' => 'hallo welt', 'en' => 'hello world', ...
-	 *
-	 * This function is useful to avoid loading thousands of files if only one
-	 * simple string is needed, for example in appinfo.php
+	 * @return string language
 	 */
-	public static function selectLanguage($text) {
-		$lang = self::findLanguage(array_keys($text));
-		return $text[$lang];
+	public function getLanguageCode() {
+		return $this->lang ? $this->lang : self::findLanguage();
 	}
 
-	/**
-	 * The given language is forced to be used while executing the current request
-	 * @param string $lang
-	 */
-	public static function forceLanguage($lang) {
-		self::$language = $lang;
-	}
-
-
 	/**
 	 * find the best language
-	 *
-	 * @param array|string $app details below
-	 *
-	 * If $app is an array, ownCloud assumes that these are the available
-	 * languages. Otherwise ownCloud tries to find the files in the l10n
-	 * folder.
-	 *
-	 * If nothing works it returns 'en'
+	 * @param string $app
 	 * @return string language
-	 */
-	public function getLanguageCode($app=null) {
-		return self::findLanguage($app);
-	}
-
-
-	/**
-	 * find the best language
-	 * @param array|string $app details below
-	 * @return string language
-	 *
-	 * If $app is an array, ownCloud assumes that these are the available
-	 * languages. Otherwise ownCloud tries to find the files in the l10n
-	 * folder.
 	 *
 	 * If nothing works it returns 'en'
 	 */
 	public static function findLanguage($app = null) {
-		if(!is_array($app) && self::$language != '') {
+		if (self::$language != '' && self::languageExists($app, self::$language)) {
 			return self::$language;
 		}
 
-		if(OC_User::getUser() && OC_Preferences::getValue(OC_User::getUser(), 'core', 'lang')) {
-			$lang = OC_Preferences::getValue(OC_User::getUser(), 'core', 'lang');
+		$config = \OC::$server->getConfig();
+		$userId = \OC_User::getUser();
+
+		if($userId && $config->getUserValue($userId, 'core', 'lang')) {
+			$lang = $config->getUserValue($userId, 'core', 'lang');
 			self::$language = $lang;
-			if(is_array($app)) {
-				$available = $app;
-				$lang_exists = array_search($lang, $available) !== false;
-			} else {
-				$lang_exists = self::languageExists($app, $lang);
-			}
-			if($lang_exists) {
+			if(self::languageExists($app, $lang)) {
 				return $lang;
 			}
 		}
 
-		$default_language = OC_Config::getValue('default_language', false);
+		$default_language = $config->getSystemValue('default_language', false);
 
 		if($default_language !== false) {
 			return $default_language;
 		}
 
-		if(isset($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
-			if(is_array($app)) {
-				$available = $app;
-			} else {
-				$available = self::findAvailableLanguages($app);
-			}
-
-			// E.g. make sure that 'de' is before 'de_DE'.
-			sort($available);
-
-			$preferences = preg_split('/,\s*/', strtolower($_SERVER['HTTP_ACCEPT_LANGUAGE']));
-			foreach($preferences as $preference) {
-				list($preferred_language) = explode(';', $preference);
-				$preferred_language = str_replace('-', '_', $preferred_language);
-				foreach($available as $available_language) {
-					if ($preferred_language === strtolower($available_language)) {
-						if (is_null($app)) {
-							self::$language = $available_language;
-						}
-						return $available_language;
-					}
-				}
-				foreach($available as $available_language) {
-					if (substr($preferred_language, 0, 2) === $available_language) {
-						if (is_null($app)) {
-							self::$language = $available_language;
-						}
-						return $available_language;
-					}
-				}
-			}
+		$lang = self::setLanguageFromRequest();
+		if($userId && !$config->getUserValue($userId, 'core', 'lang')) {
+			$config->setUserValue($userId, 'core', 'lang', $lang);
 		}
 
-		// Last try: English
-		return 'en';
+		return $lang;
 	}
 
 	/**
 	 * find the l10n directory
 	 * @param string $app App that needs to be translated
-	 * @return directory
+	 * @return string directory
 	 */
 	protected static function findI18nDir($app) {
 		// find the i18n dir
-		$i18ndir = OC::$SERVERROOT.'/core/l10n/';
+		$i18nDir = OC::$SERVERROOT.'/core/l10n/';
 		if($app != '') {
 			// Check if the app is in the app folder
 			if(file_exists(OC_App::getAppPath($app).'/l10n/')) {
-				$i18ndir = OC_App::getAppPath($app).'/l10n/';
+				$i18nDir = OC_App::getAppPath($app).'/l10n/';
 			}
 			else{
-				$i18ndir = OC::$SERVERROOT.'/'.$app.'/l10n/';
+				$i18nDir = OC::$SERVERROOT.'/'.$app.'/l10n/';
 			}
 		}
-		return $i18ndir;
+		return $i18nDir;
 	}
 
 	/**
@@ -518,17 +464,23 @@ class OC_L10N implements \OCP\IL10N {
 	 * @return array an array of available languages
 	 */
 	public static function findAvailableLanguages($app=null) {
+		// also works with null as key
+		if(isset(self::$availableLanguages[$app]) && !empty(self::$availableLanguages[$app])) {
+			return self::$availableLanguages[$app];
+		}
 		$available=array('en');//english is always available
 		$dir = self::findI18nDir($app);
 		if(is_dir($dir)) {
 			$files=scandir($dir);
 			foreach($files as $file) {
-				if(substr($file, -4, 4) === '.php' && substr($file, 0, 4) !== 'l10n') {
-					$i = substr($file, 0, -4);
+				if(substr($file, -5, 5) === '.json' && substr($file, 0, 4) !== 'l10n') {
+					$i = substr($file, 0, -5);
 					$available[] = $i;
 				}
 			}
 		}
+
+		self::$availableLanguages[$app] = $available;
 		return $available;
 	}
 
@@ -538,13 +490,40 @@ class OC_L10N implements \OCP\IL10N {
 	 * @return bool
 	 */
 	public static function languageExists($app, $lang) {
-		if ($lang == 'en') {//english is always available
+		if ($lang === 'en') {//english is always available
 			return true;
 		}
 		$dir = self::findI18nDir($app);
 		if(is_dir($dir)) {
-			return file_exists($dir.'/'.$lang.'.php');
+			return file_exists($dir.'/'.$lang.'.json');
 		}
 		return false;
 	}
+
+	/**
+	 * @return string
+	 * @throws \Punic\Exception\ValueNotInList
+	 */
+	public function getDateFormat() {
+		$locale = $this->getLanguageCode();
+		$locale = $this->transformToCLDRLocale($locale);
+		return Punic\Calendar::getDateFormat('short', $locale);
+	}
+
+	/**
+	 * @return int
+	 */
+	public function getFirstWeekDay() {
+		$locale = $this->getLanguageCode();
+		$locale = $this->transformToCLDRLocale($locale);
+		return Punic\Calendar::getFirstWeekday($locale);
+	}
+
+	private function transformToCLDRLocale($locale) {
+		if ($locale === 'sr@latin') {
+			return 'sr_latn';
+		}
+
+		return $locale;
+	}
 }
