@@ -10,7 +10,6 @@ OC.L10N.register(
     "Cron" : "Cron",
     "Email server" : "E-Mail-Server",
     "Log" : "Log",
-    "Server Status" : "Serverstatus",
     "Tips & tricks" : "Tipps & Tricks",
     "Updates" : "Updates",
     "Authentication error" : "Authentifizierungsfehler",
@@ -31,6 +30,9 @@ OC.L10N.register(
     "Unable to change password" : "Passwort konnte nicht geändert werden",
     "Enabled" : "Aktiviert",
     "Not enabled" : "Nicht aktiviert",
+    "installing and updating apps via the app store or Federated Cloud Sharing" : "das Installieren und Aktualisieren von Apps durch den App-Store oder durch Federated Cloud Sharing",
+    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
+    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL verwendet eine veraltete %s Version (%s). Bitte aktualisiere dein Betriebsystem, da ansonsten Funktionen, wie z.B. %s, nicht zuverlässig funktionieren werden.",
     "A problem occurred, please check your log files (Error: %s)" : "Es ist ein Problem aufgetreten, bitte überprüfe Deine Logdateien (Fehler: %s)",
     "Migration Completed" : "Migration komplett",
     "Group already exists." : "Gruppe existiert bereits.",
@@ -75,15 +77,17 @@ OC.L10N.register(
     "Uninstalling ...." : "Deinstallieren…",
     "Error while uninstalling app" : "Fehler beim Deinstallieren der App",
     "Uninstall" : "Deinstallieren",
+    "App update" : "App aktualisiert",
+    "An error occurred: {message}" : "Ein Fehler ist aufgetreten: {message}",
     "Select a profile picture" : "Wähle ein Profilbild",
     "Very weak password" : "Sehr schwaches Passwort",
     "Weak password" : "Schwaches Passwort",
     "So-so password" : "Durchschnittliches Passwort",
     "Good password" : "Gutes Passwort",
     "Strong password" : "Starkes Passwort",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Es ist ein Fehler aufgetreten. Bitte lade ein ASCII-kodiertes PEM-Zertifikat hoch.",
     "Valid until {date}" : "Gültig bis {date}",
     "Delete" : "Löschen",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Es ist ein Fehler aufgetreten. Bitte lade ein ASCII-kodiertes PEM-Zertifikat hoch.",
     "Groups" : "Gruppen",
     "Unable to delete {objName}" : "Löschen von {objName} nicht möglich",
     "Error creating group" : "Fehler beim Erstellen der Gruppe",
@@ -115,7 +119,7 @@ OC.L10N.register(
     "SSL" : "SSL",
     "TLS" : "TLS",
     "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP scheint zur Abfrage von Systemumgebungsvariablen nicht richtig eingerichtet zu sein. Der Test mit getenv (\"PATH\") liefert nur eine leere Antwort zurück.",
-    "Please check the installation documentation for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Bitten überprüfe die Installationsdokumentation auf Hinweise zur PHP-Konfiguration sowie die PHP-Konfiguration Deines Servers, insbesondere dann, wenn Du PHP-FPM einsetzt.",
+    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Bitte schau in der <a target=\"_blank\" href=\"%s\">Installationsdokumentation ↗</a>auf Hinweise zur PHP-Konfiguration, sowie die PHP-Konfiguration Deines Servers, insbesondere dann, wenn Du PHP-FPM einsetzt.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Die schreibgeschützte Konfiguration wurde aktiviert. Dies verhindert das Setzen einiger Einstellungen über die Web-Schnittstelle. Weiterhin muss bei jedem Update der Schreibzugriff auf die Datei händisch aktiviert werden.",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ist offenbar so konfiguriert, dass PHPDoc-Blöcke in der Anweisung entfernt werden. Dadurch sind mehrere Kern-Apps nicht erreichbar.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dies wird wahrscheinlich durch Zwischenspeicher/Beschleuniger wie etwa Zend OPcache oder eAccelerator verursacht.",
@@ -150,7 +154,9 @@ OC.L10N.register(
     "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php ist als Webcron-Dienst registriert, der die cron.php alle 15 Minuten per HTTP aufruft.",
     "Use system's cron service to call the cron.php file every 15 minutes." : "Benutze den systemeigenen Cron-Dienst, um die cron.php alle 15 Minuten aufzurufen.",
     "Enable server-side encryption" : "Serverseitige Verschlüsselung aktivieren",
-    "Encryption is a one way process. Once encryption is enabled, all files from that point forward will be encrypted on the server and it will not be possible to disable encryption at a later date. This is the final warning: Do you really want to enable encryption?" : "Verschlüsselung ist ein ein Prozess in eine Richtung. Wenn die Verschlüsselung aktiviert ist, werden alle Dateien von diesem Zeitpunkt an auf dem Server verschlüsselt und es wird nicht mehr möglich sein, die Verschlüsselung zu einem späteren Zeitpunkt zu deaktivieren. Dies ist die letzte Warnung: Möchtest Du die Verschlüsselung wirklich aktivieren?",
+    "Please read carefully before activating server-side encryption: " : "Bitte sorgfältig lesen, bevor die serverseitige Verschlüsselung aktiviert wird:",
+    "Be aware that encryption always increases the file size." : "Sei dir bewusst, dass die Verschlüsselung immer die Dateigröße erhöht.",
+    "This is the final warning: Do you really want to enable encryption?" : "Dies ist die letzte Warnung: Verschlüsselung wirklich aktivieren?",
     "Enable encryption" : "Verschlüsselung aktivieren",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Kein Verschlüsselungs-Modul geladen, bitte aktiviere ein Verschlüsselungs-Modul im Anwendungs-Menü.",
     "Select default encryption module:" : "Bite Standard-Verschlüsselungs-Modul auswählen:",
@@ -193,8 +199,8 @@ OC.L10N.register(
     "by" : "von",
     "licensed" : "Lizenziert",
     "Documentation:" : "Dokumentation:",
-    "User Documentation" : "Dokumentation für Benutzer",
-    "Admin Documentation" : "Admin-Dokumentation",
+    "User documentation" : "Dokumentation für Benutzer",
+    "Admin documentation" : "Dokumentation für Administratoren",
     "Show description …" : "Beschreibung anzeigen…",
     "Hide description …" : "Beschreibung ausblenden…",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Die App kann nicht installiert werden, weil die folgenden Abhängigkeiten nicht erfüllt sind:",
@@ -203,9 +209,8 @@ OC.L10N.register(
     "Enable experimental apps" : "Experimentelle Apps aktivieren",
     "No apps found for your version" : "Es wurden keine Apps für Deine Version gefunden",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hallo,<br><br>hier nur kurz die Mitteilung, dass Du jetzt ein %s-Konto hast.<br><br>Dein Benutzername: %s<br>Greife darauf zu: <a href=\"%s\">%s</a><br><br>",
-    "Cheers!" : "Hallo!",
+    "Cheers!" : "Noch einen schönen Tag!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hallo,\n\nhier nur kurz die Mitteilung, dass Du jetzt ein %s-Konto hast.\n\nDein Benutzername: %s\nGreife darauf zu: %s\n\n",
-    "User documentation" : "Dokumentation für Benutzer",
     "Administrator documentation" : "Dokumentation für Administratoren",
     "Online documentation" : "Online-Dokumentation",
     "Forum" : "Forum",
@@ -215,7 +220,7 @@ OC.L10N.register(
     "Desktop client" : "Desktop-Client",
     "Android app" : "Android-App",
     "iOS app" : "iOS-App",
-    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Wenn Du das Projekt unterstützen möchtest,\n⇥⇥<a href=\"https://owncloud.org/contribute\"\n⇥⇥⇥target=\"_blank\" rel=\"noreferrer\">beteilige Dich an der Entwicklung</a>\n⇥⇥oder\n⇥⇥<a href=\"https://owncloud.org/promote\"\n⇥⇥⇥target=\"_blank\" rel=\"noreferrer\">hilf mit, es bekannter zu machen</a>!",
+    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Wenn Du das Projekt unterstützen möchtest,\n<a href=\"https://owncloud.org/contribute\"\ntarget=\"_blank\" rel=\"noreferrer\">beteilige Dich an der Entwicklung</a>\noder\n<a href=\"https://owncloud.org/promote\"\ntarget=\"_blank\" rel=\"noreferrer\">hilf mit, es bekannter zu machen</a>!",
     "Show First Run Wizard again" : "Den Einrichtungsassistenten erneut anzeigen",
     "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Du verwendest <strong>%s</strong> der verfügbaren <strong>%s</strong>",
     "Password" : "Passwort",
@@ -234,7 +239,7 @@ OC.L10N.register(
     "Upload new" : "Neues hochladen",
     "Select new from Files" : "Neues aus den Dateien wählen",
     "Remove image" : "Bild entfernen",
-    "Either png or jpg. Ideally square but you will be able to crop it." : "Entweder PNG oder JPG. Im Idealfall quadratisch, Du kannst es aber beschneiden.",
+    "Either png or jpg. Ideally square but you will be able to crop it. The file is not allowed to exceed the maximum size of 20 MB." : "Entweder png oder jpg. Im Idealfall quadratisch, aber du kannst das Bild beschneiden. Es ist nicht erlaubt die Maximalgröße von 20 MB zu überschreiten.",
     "Your avatar is provided by your original account." : "Dein Avatar wird von Deinem ursprünglichen Konto bereitgestellt.",
     "Cancel" : "Abbrechen",
     "Choose as profile image" : "Als Profilbild wählen",
@@ -256,7 +261,6 @@ OC.L10N.register(
     "Create" : "Anlegen",
     "Admin Recovery Password" : "Admin-Wiederherstellungspasswort",
     "Enter the recovery password in order to recover the users files during password change" : "Gib das Wiederherstellungspasswort ein, um die Benutzerdateien während der Passwortänderung wiederherzustellen",
-    "Search Users" : "Benutzer suchen",
     "Add Group" : "Gruppe hinzufügen",
     "Group" : "Gruppe",
     "Everyone" : "Jeder",
